<?php
unset($pia_lang);
//////////////////////////////////////////////////////////////////
// About - ready
//////////////////////////////////////////////////////////////////
$pia_lang['About_Title'] = 'Garde réseau open source';
$pia_lang['About_Design'] = 'Conçu pour:';
$pia_lang['About_Exit'] = 'Logout';
$pia_lang['About_Reports'] = 'Afficher les messages';

//////////////////////////////////////////////////////////////////
// General - ready
//////////////////////////////////////////////////////////////////
$pia_lang['Gen_Delete'] = 'Supprimer';
$pia_lang['Gen_Cancel'] = 'Annuler';
$pia_lang['Gen_Okay'] = 'Ok';
$pia_lang['Gen_Purge'] = 'Purge';
$pia_lang['Gen_Backup'] = 'Sauvegarder';
$pia_lang['Gen_Restore'] = 'Restaurer';
$pia_lang['Gen_Switch'] = 'Switch';
$pia_lang['Gen_Run'] = 'Exécuter';
$pia_lang['Gen_Save'] = 'Sauvez';
$pia_lang['Gen_Close'] = 'Close';
$pia_lang['Gen_on'] = 'On';
$pia_lang['Gen_off'] = 'Off';

//////////////////////////////////////////////////////////////////
// Login Page - ready
//////////////////////////////////////////////////////////////////

$pia_lang['Login_Box'] = 'Entrez votre mot de passe';
$pia_lang['Login_Remember'] = 'Mémoriser';
$pia_lang['Login_Remember_small'] = '(valable pour 7 jours)';
$pia_lang['Login_Submit'] = "S'inscrire";
$pia_lang['Login_Psw_run'] = 'Pour changer le mot de passe, exécutez:';
$pia_lang['Login_Psw_new'] = 'nouveau_mot_de_passe';
$pia_lang['Login_Psw_folder'] = 'dans le dossier "~/pialert/back".';
$pia_lang['Login_Psw_alert'] = 'Consigne de sécurité !';
$pia_lang['Login_Psw-box'] = 'Mot de passe';
$pia_lang['Login_Toggle_Info'] = 'Informations sur le mot de passe';
$pia_lang['Login_Toggle_Info_headline'] = 'Informations sur le mot de passe';
$pia_lang['Login_Toggle_Alert_headline'] = 'Avertissement sur le mot de passe !';

//////////////////////////////////////////////////////////////////
// Sidebar
//////////////////////////////////////////////////////////////////

$pia_lang['Navigation_Devices'] = 'Dispositifs';
$pia_lang['Navigation_Services'] = 'Web Services';
$pia_lang['Navigation_Presence'] = 'Présence';
$pia_lang['Navigation_Events'] = 'Événements';
$pia_lang['Navigation_Journal'] = 'Pi.Alert Journal';
$pia_lang['Navigation_Events_Dev'] = 'Devices';
$pia_lang['Navigation_Events_Serv'] = 'Web Services';
$pia_lang['Navigation_ICMPScan'] = 'ICMP Monitoring';
$pia_lang['Navigation_Maintenance'] = 'Paramètres';
$pia_lang['Navigation_Network'] = 'Réseau';
$pia_lang['Navigation_HelpFAQ'] = 'Aide / FAQ';
$pia_lang['Navigation_UpdateCheck'] = 'Update Check';
$pia_lang['Navigation_Section_A'] = 'MAIN MENU';
$pia_lang['Navigation_Section_B'] = 'EVENTS & JOURNAL';
$pia_lang['Navigation_Section_C'] = 'SETTINGS & HELP';

//////////////////////////////////////////////////////////////////
// Device Page - ready
//////////////////////////////////////////////////////////////////

$pia_lang['Device_Title'] = 'Dispositifs';
$pia_lang['Device_Shortcut_AllDevices'] = 'Tous les appareils';
$pia_lang['Device_Shortcut_Connected'] = 'Connecté';
$pia_lang['Device_Shortcut_Favorites'] = 'Favoris';
$pia_lang['Device_Shortcut_NewDevices'] = 'Nouveau';
$pia_lang['Device_Shortcut_DownAlerts'] = 'Alertes descendantes';
$pia_lang['Device_Shortcut_Archived'] = 'Archivé';
$pia_lang['Device_Shortcut_Devices'] = 'Dispositifs';
$pia_lang['Device_Shortcut_OnlineChart_a'] = 'Présence du dispositif dans le temps (';
$pia_lang['Device_Shortcut_OnlineChart_b'] = 'h)';
$pia_lang['Device_TableHead_Name'] = 'Nom';
$pia_lang['Device_TableHead_Owner'] = 'Propriétaire';
$pia_lang['Device_TableHead_Type'] = 'Type';
$pia_lang['Device_TableHead_Favorite'] = 'Favori';
$pia_lang['Device_TableHead_Group'] = 'Groupe';
$pia_lang['Device_TableHead_Location'] = 'Site';
$pia_lang['Device_TableHead_FirstSession'] = 'Première session';
$pia_lang['Device_TableHead_LastSession'] = 'Dernière session';
$pia_lang['Device_TableHead_LastIP'] = 'Dernière IP';
$pia_lang['Device_TableHead_MAC'] = 'MAC';
$pia_lang['Device_TableHead_MACaddress'] = 'MAC-Address';
$pia_lang['Device_TableHead_LastIPOrder'] = 'Last IP Order';
$pia_lang['Device_TableHead_Rowid'] = 'Numéro de ligne';
$pia_lang['Device_TableHead_Status'] = 'Statut';
$pia_lang['Device_TableHead_ConnectionType'] = 'Connection Type';
$pia_lang['Device_Searchbox'] = 'Recherche';
$pia_lang['Device_Tablelenght'] = 'Afficher _MENU_ entrées';
$pia_lang['Device_Tablelenght_all'] = 'Tous les';
$pia_lang['Device_Table_info'] = 'Afficher _START_ à _END_ de _TOTAL_ entrées';
$pia_lang['Device_Table_nav_next'] = 'Prochain';
$pia_lang['Device_Table_nav_prev'] = 'Retour';
$pia_lang['Device_bulkEditor_mode'] = 'Bulk Editor';
$pia_lang['Device_bulkEditor_mode_quit'] = 'Quit Editor';
$pia_lang['Device_bulkEditor_selectall'] = 'Select all Host&apos;s';
$pia_lang['Device_bulkEditor_selectnone'] = 'Deselect all Host&apos;s';
$pia_lang['Device_bulkEditor_savebox_title'] = 'Fields were saved';
$pia_lang['Device_bulkEditor_savebox_noselection'] = 'No fields were selected for modification';
$pia_lang['Device_bulkEditor_savebox_mod_devices'] = 'Modified devices';
$pia_lang['Device_bulkEditor_savebox_mod_fields'] = 'Changed values';
$pia_lang['Device_bulkEditor_hostbox_title'] = 'Select the devices to be edited';
$pia_lang['Device_bulkEditor_inputbox_title'] = 'Edit fields';
$pia_lang['Device_bulkDel_button'] = 'EFFACER LES APPAREILS';
$pia_lang['Device_bulkDel_info_head'] = 'Supprimer plusieurs appareils';
$pia_lang['Device_bulkDel_info_text'] = 'Avec cette fonction, tu supprimes un ou plusieurs appareils de la base de données. Si les appareils se trouvent encore dans le réseau, ils seront éventuellement réintégrés dans la base de données, mais sans les réglages individuels.';
$pia_lang['Device_bulkDel_back_before'] = 'Nombre d&apos;appareils avant';
$pia_lang['Device_bulkDel_back_after'] = 'Nombre d&apos;appareils actuel';
$pia_lang['Device_bulkDel_back_hosts'] = 'Adresses MAC à supprimer';

//////////////////////////////////////////////////////////////////
// Presence Page - ready
//////////////////////////////////////////////////////////////////

$pia_lang['Presence_Title'] = 'Présence par appareil';
$pia_lang['Presence_Shortcut_AllDevices'] = 'Tous les appareils';
$pia_lang['Presence_Shortcut_Connected'] = 'Connecté';
$pia_lang['Presence_Shortcut_Favorites'] = 'Favoris';
$pia_lang['Presence_Shortcut_NewDevices'] = 'Nouveau';
$pia_lang['Presence_Shortcut_DownAlerts'] = 'Alertes descendantes';
$pia_lang['Presence_Shortcut_Archived'] = 'Archivé';
$pia_lang['Presence_Shortcut_Devices'] = 'Dispositifs';

// Localizationfiles under pialert/front/lib/AdminLTE/bower_components/fullcalendar/dist/locale
$pia_lang['Presence_CallHead_Devices'] = 'Dispositifs';
$pia_lang['Presence_CalHead_lang'] = 'fr';
$pia_lang['Presence_CalHead_year'] = 'Année';
$pia_lang['Presence_CalHead_quarter'] = 'trimestre';
$pia_lang['Presence_CalHead_month'] = 'Mois';
$pia_lang['Presence_CalHead_week'] = 'Semaine';
$pia_lang['Presence_CalHead_day'] = 'day';

//////////////////////////////////////////////////////////////////
// Events Page - ready
//////////////////////////////////////////////////////////////////

$pia_lang['Events_Title'] = 'Événements';
$pia_lang['Events_Periodselect_today'] = 'Aujourd&apos;hui';
$pia_lang['Events_Periodselect_LastWeek'] = 'Semaine dernière';
$pia_lang['Events_Periodselect_LastMonth'] = 'Dernier mois';
$pia_lang['Events_Periodselect_LastYear'] = 'Dernière année';
$pia_lang['Events_Periodselect_All'] = 'Tous les événements';
$pia_lang['Events_Shortcut_AllEvents'] = 'Tous les événements';
$pia_lang['Events_Shortcut_Sessions'] = 'Sessions';
$pia_lang['Events_Shortcut_MissSessions'] = 'Sessions manquantes';
$pia_lang['Events_Shortcut_VoidSessions'] = 'Sessions terminées';
$pia_lang['Events_Shortcut_NewDevices'] = 'Nouveau';
$pia_lang['Events_Shortcut_DownAlerts'] = 'Alertes descendantes';
$pia_lang['Events_Shortcut_Events'] = 'Événements';
$pia_lang['Events_TableHead_Order'] = 'Ordenar';
$pia_lang['Events_TableHead_Device'] = 'Dispositifs';
$pia_lang['Events_TableHead_Owner'] = 'Propriétaire';
$pia_lang['Events_TableHead_Date'] = 'Date';
$pia_lang['Events_TableHead_EventType'] = 'Évènement Type';
$pia_lang['Events_TableHead_Connection'] = 'Connexion';
$pia_lang['Events_TableHead_Disconnection'] = 'Déconnection';
$pia_lang['Events_TableHead_Duration'] = 'Durée';
$pia_lang['Events_TableHead_DurationOrder'] = 'Duration Order';
$pia_lang['Events_TableHead_IP'] = 'IP';
$pia_lang['Events_TableHead_IPOrder'] = 'IP Order';
$pia_lang['Events_TableHead_AdditionalInfo'] = 'Infos complémentaires';
$pia_lang['Events_Searchbox'] = 'Recherche';
$pia_lang['Events_Tablelenght'] = 'Afficher _MENU_ entrées';
$pia_lang['Events_Tablelenght_all'] = 'Tous les';
$pia_lang['Events_Table_info'] = 'Afficher _START_ à _END_ de _TOTAL_ entrées';
$pia_lang['Events_Table_nav_next'] = 'Prochain';
$pia_lang['Events_Table_nav_prev'] = 'Retour';

//////////////////////////////////////////////////////////////////
// WebServices Events Page
//////////////////////////////////////////////////////////////////

$pia_lang['WebServices_Events_Title'] = 'Web Services - Events';
$pia_lang['WebServices_Events_Shortcut_All'] = 'All Events';
$pia_lang['WebServices_Events_Shortcut_HTTP2xx'] = 'HTTP Code 2xx';
$pia_lang['WebServices_Events_Shortcut_HTTP3xx'] = 'HTTP Code 3xx';
$pia_lang['WebServices_Events_Shortcut_HTTP4xx'] = 'HTTP Code 4xx';
$pia_lang['WebServices_Events_Shortcut_HTTP5xx'] = 'HTTP Code 5xx';
$pia_lang['WebServices_Events_Shortcut_Down'] = 'Down';
$pia_lang['WebServices_Events_TableHead_URL'] = 'URL';
$pia_lang['WebServices_Events_TableHead_TargetIP'] = 'Target IP';
$pia_lang['WebServices_Events_TableHead_ScanTime'] = 'Scan Time';
$pia_lang['WebServices_Events_TableHead_StatusCode'] = 'Status Code';
$pia_lang['WebServices_Events_TableHead_ResponsTime'] = 'Response Time';

//////////////////////////////////////////////////////////////////
// Device Details Page - ready
//////////////////////////////////////////////////////////////////

$pia_lang['DevDetail_Periodselect_today'] = 'Aujourd&apos;hui';
$pia_lang['DevDetail_Periodselect_LastWeek'] = 'Semaine dernière';
$pia_lang['DevDetail_Periodselect_LastMonth'] = 'Dernier mois';
$pia_lang['DevDetail_Periodselect_LastYear'] = 'Dernière année';
$pia_lang['DevDetail_Periodselect_All'] = 'Tous les événements';
$pia_lang['DevDetail_Shortcut_CurrentStatus'] = 'Statut actuel';
$pia_lang['DevDetail_Shortcut_Sessions'] = 'Sessions';
$pia_lang['DevDetail_Shortcut_Presence'] = 'Présence';
$pia_lang['DevDetail_Shortcut_DownAlerts'] = 'Alertes descendantes';
$pia_lang['DevDetail_Tab_Details'] = 'Détails';
$pia_lang['DevDetail_Tab_Nmap'] = 'Tools';
$pia_lang['DevDetail_Tab_Sessions'] = 'Sessions';
$pia_lang['DevDetail_Tab_Presence'] = 'Présence';
$pia_lang['DevDetail_Tab_Events'] = 'Événements';
$pia_lang['DevDetail_MainInfo_Title'] = 'Infos principales';
$pia_lang['DevDetail_MainInfo_mac'] = 'MAC';
$pia_lang['DevDetail_MainInfo_Name'] = 'Nom';
$pia_lang['DevDetail_MainInfo_Owner'] = 'Propriétaire';
$pia_lang['DevDetail_MainInfo_Type'] = 'Type';
$pia_lang['DevDetail_MainInfo_Vendor'] = 'Vendeur';
$pia_lang['DevDetail_MainInfo_Model'] = 'Model';
$pia_lang['DevDetail_MainInfo_Serialnumber'] = 'Serial';
$pia_lang['DevDetail_MainInfo_Favorite'] = 'Favori';
$pia_lang['DevDetail_MainInfo_Group'] = 'Groupe';
$pia_lang['DevDetail_MainInfo_Location'] = 'Site';
$pia_lang['DevDetail_MainInfo_Comments'] = 'Commentaire';
$pia_lang['DevDetail_MainInfo_Network'] = 'Nœud de réseau';
$pia_lang['DevDetail_MainInfo_Network_Port'] = 'Connecté au port';
$pia_lang['DevDetail_MainInfo_Network_ConnectType'] = 'Connection Type';
$pia_lang['DevDetail_SessionInfo_Title'] = 'Infos sur la session';
$pia_lang['DevDetail_SessionInfo_Status'] = 'Statut';
$pia_lang['DevDetail_SessionInfo_FirstSession'] = 'Première session';
$pia_lang['DevDetail_SessionInfo_LastSession'] = 'Dernière session';
$pia_lang['DevDetail_SessionInfo_LastIP'] = 'Dernière IP';
$pia_lang['DevDetail_SessionInfo_StaticIP'] = 'IP statique';
$pia_lang['DevDetail_Network_Titel'] = 'Réseau';
$pia_lang['DevDetail_EveandAl_Title'] = 'Configuration des événements et alertes';
$pia_lang['DevDetail_EveandAl_ScanCycle'] = 'Cycle d&apos;analyse';
$pia_lang['DevDetail_EveandAl_AlertAllEvents'] = 'Alerter tous les événements';
$pia_lang['DevDetail_EveandAl_AlertDown'] = 'Signaler Down';
$pia_lang['DevDetail_EveandAl_Skip'] = 'Ignorer les notifications répétées durant';
$pia_lang['DevDetail_EveandAl_NewDevice'] = 'Nouveau dispositif';
$pia_lang['DevDetail_EveandAl_Archived'] = 'Archivé';
$pia_lang['DevDetail_EveandAl_RandomMAC'] = 'MAC aléatoire';
$pia_lang['DevDetail_EveandAl_ScanCycle_a'] = 'Dispositif d&apos;analyse (1 min)';
$pia_lang['DevDetail_EveandAl_ScanCycle_z'] = 'Ne scannez pas le dispositif (0 min)';
$pia_lang['DevDetail_button_Delete'] = 'Supprimer le dispositif';
$pia_lang['DevDetail_button_Delete_Warning'] = 'Are you sure you want to delete this device?<br>(maybe you prefer to archive it)';
$pia_lang['DevDetail_button_DeleteEvents'] = 'Supprimer les événements';
$pia_lang['DevDetail_button_DeleteEvents_Warning'] = 'Êtes-vous sûr de vouloir supprimer tous les événements de cet appareil <br><br>(cela effacera l&apos;historique des événements et des sessions et pourrait aider à la mise en place de notifications constantes (persistantes))';
$pia_lang['DevDetail_button_Reset'] = 'Rejeter les modifications';
$pia_lang['DevDetail_button_Save'] = 'Sauvez';
$pia_lang['DevDetail_SessionTable_Order'] = 'Ordre';
$pia_lang['DevDetail_SessionTable_Connection'] = 'Connexion';
$pia_lang['DevDetail_SessionTable_Disconnection'] = 'Déconnexion';
$pia_lang['DevDetail_SessionTable_Duration'] = 'Durée';
$pia_lang['DevDetail_SessionTable_IP'] = 'IP';
$pia_lang['DevDetail_SessionTable_Additionalinfo'] = 'Infos complémentaires';
$pia_lang['DevDetail_Events_CheckBox'] = 'Masquer les événements de connexion';
$pia_lang['DevDetail_Tools_nmap_buttonFast'] = 'Scan rapide';
$pia_lang['DevDetail_Tools_nmap_buttonDefault'] = 'Scan par défaut';
$pia_lang['DevDetail_Tools_nmap_buttonDetail'] = 'Scan détaillé';
$pia_lang['DevDetail_Tools_nmap_buttonFast_text'] = 'Scan rapide: Scanner moins de ports (100) que le scan par défaut (quelques secondes)';
$pia_lang['DevDetail_Tools_nmap_buttonDefault_text'] = 'Scan par défaut: Nmap scanne les 1000 premiers ports pour chaque protocole de scan demandé. Cela permet de capturer environ 93% des ports TCP et 49% des ports UDP. (environ 5 secondes)';
$pia_lang['DevDetail_Tools_nmap_buttonDetail_text'] = 'Scan rapide: Analyse par défaut avec détection du système d&apos;exploitation, détection de la version, analyse des scripts et traceroute activés (jusqu&apos;à 30 secondes ou plus)';
$pia_lang['DevDetail_Tools_WOL'] = 'Send Wol command to ';
$pia_lang['DevDetail_Tools_WOL_noti'] = 'Wake-on-LAN';
$pia_lang['DevDetail_Tools_WOL_noti_text'] = 'The Wake-on-LAN command is sent to the broadcast address. If the target is not in the subnet/vlan of Pi.Alert, the target device will not respond.';
$pia_lang['BackDevDetail_Tools_WOL_okay'] = 'The command was executed';
$pia_lang['BackDevDetail_Tools_WOL_error'] = 'The command was not executed';

//////////////////////////////////////////////////////////////////
// WebServices Details Page
//////////////////////////////////////////////////////////////////

$pia_lang['WebServices_Title'] = 'Web Services';
$pia_lang['WebServices_unknown_Device'] = 'Unknown Device';
$pia_lang['WebServices_tablehead_TargetIP'] = 'Target IP';
$pia_lang['WebServices_tablehead_ScanTime'] = 'Scan Time';
$pia_lang['WebServices_tablehead_Status_Code'] = 'HTTP Status';
$pia_lang['WebServices_tablehead_Response_Time'] = 'Response Time';
$pia_lang['WebServices_Tab_Graph'] = 'Stats';
$pia_lang['WebServices_label_URL'] = 'URL';
$pia_lang['WebServices_label_Tags'] = 'Tag';
$pia_lang['WebServices_label_MAC'] = 'Device';
$pia_lang['WebServices_label_MAC_Select'] = 'Select';
$pia_lang['WebServices_label_Notes'] = 'Note';
$pia_lang['WebServices_label_TargetIP'] = 'Target IP';
$pia_lang['WebServices_label_StatusCode'] = 'HTTP Status';
$pia_lang['WebServices_label_ScanTime'] = 'Scan Time';
$pia_lang['WebServices_label_Response_Time'] = 'Response Time';
$pia_lang['WebServices_label_AlertEvents'] = 'All Events';
$pia_lang['WebServices_label_AlertDown'] = 'Down Events';
$pia_lang['WebServices_label_Notification'] = 'Notify';
$pia_lang['WebServices_Chart_a'] = 'Service Status over the last';
$pia_lang['WebServices_Chart_b'] = 'hours';
$pia_lang['WebServices_Page_down'] = 'Offline';
$pia_lang['WebServices_button_Delete_label'] = 'Delete Service';
$pia_lang['WebServices_button_Delete_Warning'] = 'Are you sure you want to delete this web service?';
$pia_lang['WebServices_headline_NewService'] = 'New Web Service';
$pia_lang['WebServices_Events_all'] = 'All Events';
$pia_lang['WebServices_Events_down'] = 'Down';
$pia_lang['WebServices_Events_none'] = 'none';
$pia_lang['WebServices_BoxTitle_General'] = 'General';
$pia_lang['WebServices_Stats_Code'] = 'Page Status';
$pia_lang['WebServices_Stats_Time'] = 'Response Time';
$pia_lang['WebServices_Stats_Time_min'] = 'Fastest';
$pia_lang['WebServices_Stats_Time_max'] = 'Slowest';
$pia_lang['WebServices_Stats_Location'] = 'Emplacement';
$pia_lang['WebServices_Stats_IP'] = 'IP actuelle';
$pia_lang['WebServices_Stats_IPLocation'] = 'Mapping des pays';
$pia_lang['WebServices_Stats_comment_a'] = '(Calculé à partir de toutes les analyses de ce service)';

//////////////////////////////////////////////////////////////////
// WebServices Details Page - Backend
//////////////////////////////////////////////////////////////////

$pia_lang['BackWebServices_UpdServ'] = 'The web service was updated';
$pia_lang['BackWebServices_UpdServError'] = 'The web service was not updated';
$pia_lang['BackWebServices_InsServ'] = 'The web service was saved';
$pia_lang['BackWebServices_InsServError'] = 'The web service was not saved';
$pia_lang['BackWebServices_DelServ'] = 'The web service was deleted from the database';
$pia_lang['BackWebServices_DelServError'] = 'The web service could not be deleted, or could not be deleted completely';

//////////////////////////////////////////////////////////////////
// Page de Surveillance ICMP
//////////////////////////////////////////////////////////////////

$pia_lang['ICMPMonitor_Title'] = 'Surveillance ICMP';
$pia_lang['ICMPMonitor_headline_IP'] = 'Surveiller une nouvelle adresse IP';
$pia_lang['ICMPMonitor_label_IP'] = 'IP de l&apos;hôte';
$pia_lang['ICMPMonitor_label_Hostname'] = 'Nom d&apos;hôte';
$pia_lang['ICMPMonitor_label_RTT'] = 'RTT moyen';
$pia_lang['BackICMP_mon_disabled'] = 'La surveillance ICMP est désactivée';
$pia_lang['BackICMP_mon_enabled'] = 'La surveillance ICMP est activée';
$pia_lang['BackICMP_mon_InsICMP'] = 'L&apos;hôte ICMP a été enregistré';
$pia_lang['BackICMP_mon_InsICMPError'] = 'L&apos;hôte ICMP n&apos;a pas été enregistré';
$pia_lang['BackICMP_mon_DelICMP'] = 'L&apos;hôte ICMP a été supprimé de la base de données';
$pia_lang['BackICMP_mon_DelICMPError'] = 'L&apos;hôte ICMP n&apos;a pas pu être supprimé, ou n\'a pas été complètement supprimé';
$pia_lang['BackICMP_mon_UpdICMP'] = 'L&apos;hôte ICMP a été mis à jour';
$pia_lang['BackICMP_mon_UpdICMPError'] = 'L&apos;hôte ICMP n&apos;a pas pu être mis à jour';
$pia_lang['ICMPMonitor_Shortcut_Online'] = 'En ligne';
$pia_lang['ICMPMonitor_Shortcut_Offline'] = 'Hors ligne/Indisponible';
$pia_lang['ICMPMonitor_Availability'] = 'Availability';

/////////////////////////////////////////////////////////////////////////////
// Maintenance Page - ready
/////////////////////////////////////////////////////////////////////////////

$pia_lang['Maintenance_Title'] = 'Réglages et maintenance';
$pia_lang['Maintenance_database_path'] = 'Répertoire des bases de données';
$pia_lang['Maintenance_database_size'] = 'Taille de la base de données';
$pia_lang['Maintenance_database_lastmod'] = 'Dernière modification';
$pia_lang['Maintenance_database_backup'] = 'Sauvegarde des bases de données';
$pia_lang['Maintenance_config_backup'] = 'Config Backups';
$pia_lang['Maintenance_database_backup_found'] = 'sauvegardes ont été trouvées';
$pia_lang['Maintenance_database_backup_total'] = 'utilisation totale du disque';
$pia_lang['Maintenance_arp_status'] = 'Statut du scan';
$pia_lang['Maintenance_arp_status_off'] = 'est actuellement désactivé';
$pia_lang['Maintenance_arp_status_on'] = 'scan(s) en cours d&apos;exécution';
$pia_lang['Maintenance_notification_config'] = 'Notifications (Devices, ICMP)';
$pia_lang['Maintenance_notification_config_webmon'] = 'Notifications (Service Mon.)';
$pia_lang['Maintenance_Tools_Logviewer_Scan'] = 'Scan';
$pia_lang['Maintenance_Tools_Logviewer_Scan_empty'] = 'Il est probablement en train d&apos;effectuer un scan';
$pia_lang['Maintenance_Tools_Logviewer_IPLog'] = 'Internet IP';
$pia_lang['Maintenance_Tools_Logviewer_IPLog_empty'] = 'Pas de log disponible';
$pia_lang['Maintenance_Tools_Logviewer_Vendor'] = 'Mise à jour du vendeur';
$pia_lang['Maintenance_Tools_Logviewer_Vendor_empty'] = 'Pas de log disponible';
$pia_lang['Maintenance_Tools_Logviewer_Cleanup'] = 'Nettoyage';
$pia_lang['Maintenance_Tools_Logviewer_Cleanup_empty'] = 'Pas de log disponible';
$pia_lang['Maintenance_Tools_Logviewer_Nmap'] = 'Nmap (Session)';
$pia_lang['Maintenance_Tools_Logviewer_Nmap_empty'] = 'Pas de log disponible';
$pia_lang['Maintenance_Tools_Logviewer_WebServices'] = 'Web Services';
$pia_lang['Maintenance_Tools_Logviewer_WebServices_empty'] = 'Pas de log disponible';
$pia_lang['Maintenance_Tools_Logviewer_WOL'] = 'Wake-on-LAN (Session)';
$pia_lang['Maintenance_Tools_Logviewer_WOL_empty'] = 'Pas de log disponible';
$pia_lang['Maintenance_themeselector_lable'] = 'Sélectionnez la peau';
$pia_lang['Maintenance_themeselector_empty'] = 'Choisir une peau';
$pia_lang['Maintenance_themeselector_apply'] = 'Appliquer';
$pia_lang['Maintenance_lang_selector_lable'] = 'Sélectionnez la langue';
$pia_lang['Maintenance_lang_selector_empty'] = 'Choisir la langue';
$pia_lang['Maintenance_lang_en_us'] = 'Anglais (US)';
$pia_lang['Maintenance_lang_de_de'] = 'Allemand (DE)';
$pia_lang['Maintenance_lang_es_es'] = 'Espagnol (ES)';
$pia_lang['Maintenance_lang_fr_fr'] = 'Français (FR)';
$pia_lang['Maintenance_lang_selector_apply'] = 'Appliquer';
$pia_lang['Maintenance_Tools_Tab_Settings'] = 'Paramètres';
$pia_lang['Maintenance_Tools_Tab_Tools'] = 'Maintenance';
$pia_lang['Maintenance_Tools_Tab_BackupRestore'] = 'Sauvegarde / Restauration';
$pia_lang['Maintenance_Tools_Tab_Subheadline_a'] = 'Généralités';
$pia_lang['Maintenance_Tools_Tab_Subheadline_b'] = 'Configurer l&apos;aperçu des appareils';
$pia_lang['Maintenance_Tools_Tab_Subheadline_c'] = 'Sécurité';
$pia_lang['Maintenance_Tools_Tab_Subheadline_d'] = 'Modules';
$pia_lang['Maintenance_Tools_Tab_Settings_Intro'] = 'Les options mentionnées ici entraînent des modifications de configuration côté serveur. Ces modifications concernent donc tous les appareils qui accèdent à cette page.';
$pia_lang['Maintenance_Tool_darkmode'] = 'Dark Mode';
$pia_lang['Maintenance_Tool_darkmode_noti'] = 'Changement d&apos;affichage';
$pia_lang['Maintenance_Tool_darkmode_noti_text'] = 'Permet de passer de l&apos;affichage clair à l&apos;affichage foncé. Si la commutation ne fonctionne pas correctement, essayez d&apos;effacer le cache du navigateur.';
$pia_lang['Maintenance_Tool_onlinehistorygraph'] = 'History Graph';
$pia_lang['Maintenance_Tool_onlinehistorygraph_noti'] = 'Historique des activités';
$pia_lang['Maintenance_Tool_onlinehistorygraph_noti_text'] = 'Désactive/active l&apos;historique des activités sur la page de l&apos;appareil et sur la page de présence.';
$pia_lang['Maintenance_Tool_webservicemon'] = 'Web Service Mon.';
$pia_lang['Maintenance_Tool_webservicemon_noti'] = 'Web Service Monitoring';
$pia_lang['Maintenance_Tool_webservicemon_noti_text'] = 'Enables or disables the web service monitoring for Pi.Alert. With activation, additional elements are displayed in the interface. With deactivation, they disappear again.';
$pia_lang['Maintenance_Tool_icmpmon'] = 'Surveillance ICMP';
$pia_lang['Maintenance_Tool_icmpmon_noti'] = 'Surveillance ICMP';
$pia_lang['Maintenance_Tool_icmpmon_noti_text'] = 'Active ou désactive la surveillance ICMP pour Pi.Alert. En l&apos;activant, des éléments supplémentaires seront affichés dans l&apos;interface. En la désactivant, ces éléments disparaîtront.';
$pia_lang['Maintenance_Tool_mainscan'] = 'Numérisation Principale';
$pia_lang['Maintenance_Tool_mainscan_noti'] = 'Numérisation Principale';
$pia_lang['Maintenance_Tool_mainscan_noti_text'] = 'Active ou désactive la méthode principale de numérisation pour Pi.Alert (numérisation ARP). La collecte de données à partir de sources externes configurées reste active.';
$pia_lang['Maintenance_Tool_DevListCol_noti'] = 'Configurer l&apos;aperçu des appareils';
$pia_lang['Maintenance_Tool_DevListCol_noti_text'] = 'Souhaitez-vous enregistrer les modifications que vous avez apportées ? Cette modification s&apos;applique à tous les appareils avec lesquels vous accédez à cette page.';
$pia_lang['Maintenance_Tool_setapikey_false'] = 'Pas de clé API définie';
$pia_lang['Maintenance_Tool_setapikey'] = 'Définir la clé API';
$pia_lang['Maintenance_Tool_setapikey_text'] = 'Avec la clé API, il est possible de faire des requêtes à la base de données sans devoir utiliser le site web. Cela peut être le cas lorsqu&apos;un autre service ou site web doit accéder aux données de cette base de données. Si une clé API existe déjà, elle est remplacée.';
$pia_lang['Maintenance_Tool_setapikey_noti'] = 'Configuration de la clé API';
$pia_lang['Maintenance_Tool_setapikey_noti_text'] = 'Tu souhaites remplacer une éventuelle clé API existante par une nouvelle clé ? Les clés existantes ne seront alors plus utilisables.';
$pia_lang['Maintenance_Tool_ignorelist'] = 'Liste d&apos;ignorés';
$pia_lang['Maintenance_Tool_ignorelist_false'] = 'Aucune liste d&apos;ignorés configurée';
$pia_lang['Maintenance_arpscantimer_empty'] = 'Définir un timer';
$pia_lang['Maintenance_Tool_arpscansw'] = 'Arrêter/démarrer le scan';
$pia_lang['Maintenance_Tool_arpscansw_text'] = 'Active ou désactive le scan arp. Si aucune période n&apos;a été définie lors de l&apos;activation de la minuterie, Pi.Alert se remet en marche après une pause de 10 minutes avec le prochain scan en cours. Les scans déjà en cours ne sont pas interrompus.';
$pia_lang['Maintenance_Tool_arpscansw_noti'] = 'Arrêter/démarrer le scan arp';
$pia_lang['Maintenance_Tool_arpscansw_noti_text'] = 'Si le scan est désactivé, il reste éteint jusqu&apos;à ce qu&apos;il soit réactivé.';
$pia_lang['Maintenance_Tool_test_notification'] = 'Tester les notifications';
$pia_lang['Maintenance_Tool_test_notification_text'] = 'Rapport de test pour tous les services activés.';
$pia_lang['Maintenance_Tool_test_notification_noti'] = 'Notification de test';
$pia_lang['Maintenance_Tool_test_notification_noti_text'] = 'Faut-il effectuer un test de notification sur tous les services de notification configurés et activés ?';
$pia_lang['Maintenance_Tool_del_alldev'] = 'Effacer tous les appareils';
$pia_lang['Maintenance_Tool_del_alldev_text'] = 'Tous les appareils seront supprimés de la base de données.';
$pia_lang['Maintenance_Tool_del_alldev_noti'] = 'Effacer tous les appareils';
$pia_lang['Maintenance_Tool_del_alldev_noti_text'] = 'Êtes-vous sûr de vouloir supprimer tous les appareils ?';
$pia_lang['Maintenance_Tool_del_unknowndev'] = 'Effacer les appareils (unknown)';
$pia_lang['Maintenance_Tool_del_unknowndev_text'] = 'Tous les appareils portant le nom (unknown) seront supprimés de la base de données.';
$pia_lang['Maintenance_Tool_del_unknowndev_noti'] = 'Effacer les appareils (unknown)';
$pia_lang['Maintenance_Tool_del_unknowndev_noti_text'] = 'Êtes-vous sûr de vouloir supprimer tous les appareils (unknown) de la base de données ?';
$pia_lang['Maintenance_Tool_del_allevents'] = 'Effacer tous les événements';
$pia_lang['Maintenance_Tool_del_allevents_text'] = 'Tous les événements sont supprimés de la base de données. Cela réinitialise également la présence. Il peut y avoir des sessions invalides à partir de ce moment. Une analyse pendant que l&apos;appareil concerné est "online" devrait résoudre le problème.';
$pia_lang['Maintenance_Tool_del_allevents_noti'] = 'Effacer tous les événements';
$pia_lang['Maintenance_Tool_del_allevents_noti_text'] = 'Êtes-vous sûr de vouloir supprimer tous les événements de la base de données ? Cela réinitialise la présence de tous les appareils.';
$pia_lang['Maintenance_Tool_del_Inactive_Hosts'] = 'Supprimer les appareils inactifs';
$pia_lang['Maintenance_Tool_del_Inactive_Hosts_text'] = 'Tous les appareils inactifs depuis 30 jours sont supprimés. Les événements de ces appareils sont également supprimés de la base de données.';
$pia_lang['Maintenance_Tool_backup'] = 'DB Sauvegarde';
$pia_lang['Maintenance_Tool_backup_text'] = 'Les sauvegardes de la base de données se trouvent dans le répertoire de la base de données, compactées sous forme d&apos;archives zip, nommées avec leur date de création. Il n&apos;y a pas de nombre maximal de sauvegardes.';
$pia_lang['Maintenance_Tool_backup_noti'] = 'DB Sauvegarde';
$pia_lang['Maintenance_Tool_backup_noti_text'] = 'Êtes-vous sûr de vouloir sauvegarder la base de données maintenant ? Vérifiez qu&apos;aucune analyse n&apos;est en cours.';
$pia_lang['Maintenance_Tool_restore'] = 'Restauration de la DB';
$pia_lang['Maintenance_Tool_restore_blocked'] = 'non disponible';
$pia_lang['Maintenance_Tool_restore_text'] = 'La sauvegarde la plus récente peut être restaurée via cette fonction. Les sauvegardes plus anciennes doivent être restaurées manuellement. Il est recommandé d&apos;effectuer un contrôle d&apos;intégrité après la restauration si la base de données était ouverte lors de la sauvegarde.';
$pia_lang['Maintenance_Tool_restore_noti'] = 'Restauration de la DB';
$pia_lang['Maintenance_Tool_restore_noti_text'] = 'Êtes-vous sûr de vouloir restaurer la base de données à partir de la sauvegarde la plus récente ? Vérifiez qu&apos;aucune analyse n&apos;est actuellement en cours.';
$pia_lang['Maintenance_Tool_latestdb_download'] = 'Télécharger la dernière sauvegarde DB';
$pia_lang['Maintenance_Tool_latestconf_download'] = 'Télécharger le dernier pialert.conf';
$pia_lang['Maintenance_Tool_purgebackup'] = 'Nettoyer les sauvegardes';
$pia_lang['Maintenance_Tool_purgebackup_text'] = 'Toutes les autres sauvegardes seront supprimées, à l&apos;exception des 3 dernières.';
$pia_lang['Maintenance_Tool_purgebackup_noti'] = 'Nettoyer les sauvegardes';
$pia_lang['Maintenance_Tool_purgebackup_noti_text'] = 'Êtes-vous sûr de vouloir supprimer toutes les sauvegardes, sauf les 3 dernières ?';
$pia_lang['Maintenance_Tool_del_ActHistory'] = 'Suppression de l&apos;activité réseau';
$pia_lang['Maintenance_Tool_del_ActHistory_text'] = 'Le graphique de l&apos;activité réseau est réinitialisé. Les événements ne sont pas affectés.';
$pia_lang['Maintenance_Tool_del_ActHistory_noti'] = 'Supprimer l&apos;activité réseau';
$pia_lang['Maintenance_Tool_del_ActHistory_noti_text'] = 'Êtes-vous sûr de vouloir réinitialiser l&apos;activité réseau ?';
$pia_lang['Maintenance_Tool_loginenable'] = 'Activer le login';
$pia_lang['Maintenance_Tool_loginenable_text'] = 'Après l&apos;activation, tu arrives automatiquement sur la page de connexion. Si tu n&apos;as pas encore défini de mot de passe, "123456" est le mot de passe par défaut.';
$pia_lang['Maintenance_Tool_loginenable_noti'] = 'Activer le login';
$pia_lang['Maintenance_Tool_loginenable_noti_text'] = 'Es-tu sûr de vouloir activer le login ?';
$pia_lang['Maintenance_Tool_logindisable'] = 'Désactiver le login';
$pia_lang['Maintenance_Tool_logindisable_text'] = 'Le login est désactivé. Chaque utilisateur a maintenant à nouveau la possibilité d&apos;accéder au site Pi.Alert.';
$pia_lang['Maintenance_Tool_logindisable_noti'] = 'Désactiver le login';
$pia_lang['Maintenance_Tool_logindisable_noti_text'] = 'Es-tu sûr de vouloir désactiver le login ?';
$pia_lang['Maintenance_ConfEditor_Start'] = 'Modifier la config Pi.Alert';
$pia_lang['Maintenance_ConfEditor_Hint'] = 'Remarques sur l&apos;éditeur';
$pia_lang['Maintenance_ConfEditor_Backup'] = 'Créer une sauvegarde';
$pia_lang['Maintenance_ConfEditor_Restore'] = 'Vers la dernière version';
$pia_lang['Maintenance_ConfEditor_Restore_noti'] = 'Vers la version précédente';
$pia_lang['Maintenance_ConfEditor_Restore_noti_text'] = 'C&apos;est la dernière version du fichier de configuration qui est restaurée. La "version précédente" est soit celle de la dernière sauvegarde, soit la version antérieure à la dernière sauvegarde. Selon la plus récente.';
$pia_lang['Maintenance_ConfEditor_Backup_info'] = 'Outre le fichier "pialert-prev.bak", une autre sauvegarde est créée avec la date et l&apos;heure actuelles. Cette sauvegarde doit être restaurée manuellement en cas de besoin (renommer "pialert.conf"). Un fichier "pialert-prev.bak" existant est toujours écrasé.';
$pia_lang['Maintenance_ConfEditor_Restore_info'] = 'Cette fonction restaure le fichier denfiguration à partir du fichier "pialert-prev.bak". Le fichier "pialert-prev.bak" est créé lors de l&apos;enregistrement et de la création d&apos;une sauvegarde.';
$pia_lang['Maintenance_ConfEditor_Save_info'] = 'Le contenu du champ de texte avec les éventuelles modifications est enregistré dans le fichier "pialert.conf". La configuration précédente est sauvegardée en tant que "pialert-prev.bak". A chaque sauvegarde, le fichier "pialert-prev.bak" est toujours écrasé par le fichier de configuration précédent.';
$pia_lang['Maintenance_Tool_ConfBackup'] = 'Créer une Sauvegarde de la Configuration';
$pia_lang['Maintenance_Tool_ConfBackup_text'] = 'En plus du fichier "pialert-prev.bak", une autre sauvegarde est créée avec la date et l\'heure actuelles. Cette sauvegarde doit être restaurée manuellement en cas de besoin (la renommer en "pialert.conf").';

/////////////////////////////////////////////////////////////////////////////
// Maintenance Page (Backend) - ready
/////////////////////////////////////////////////////////////////////////////

$pia_lang['BackDevices_Arpscan_disabled'] = 'arp-scan automatique désactivé.';
$pia_lang['BackDevices_Arpscan_enabled'] = 'arp-scan automatique activé.';
$pia_lang['BackDevices_setapikey'] = 'La clé API a été définie';
$pia_lang['BackDevices_test_notification'] = 'Le message de test a été envoyé';
$pia_lang['BackDevices_darkmode_disabled'] = 'Mode clair activé.';
$pia_lang['BackDevices_darkmode_enabled'] = 'Mode sombre activé.';
$pia_lang['BackDevices_webservicemon_disabled'] = 'Web Service Monitoring Disabled';
$pia_lang['BackDevices_webservicemon_enabled'] = 'Web Service Monitoring Enabled';
$pia_lang['BackDevices_MainScan_disabled'] = 'La numérisation principale est désactivée';
$pia_lang['BackDevices_MainScan_enabled'] = 'La numérisation principale est activée';
$pia_lang['BackDevices_onlinehistorygraph_disabled'] = 'Historique d&apos;activité désactivé.';
$pia_lang['BackDevices_onlinehistorygraph_enabled'] = 'Historique d&apos;activité activé.';
$pia_lang['BackDevices_Restore_CopError'] = 'La base de données originale n&apos;a pas pu être copiée.';
$pia_lang['BackDevices_Restore_okay'] = 'La restauration a été effectuée avec succès.';
$pia_lang['BackDevices_Restore_Failed'] = 'La restauration a échoué. Restaurez manuellement la sauvegarde.';
$pia_lang['BackDevices_Backup_WALError'] = 'The original database was not copied because transactions may be open.';
$pia_lang['BackDevices_Backup_IntegrityError'] = 'The copied database has not passed the integrity check.';
$pia_lang['BackDevices_Backup_CopError'] = 'La base de données originale n&apos;a pas pu être sauvegardée.';
$pia_lang['BackDevices_Backup_okay'] = 'La sauvegarde s&apos;est terminée avec succès.';
$pia_lang['BackDevices_Backup_Failed'] = 'La sauvegarde a été partiellement exécutée. L&apos;archive est soit vide, soit inexistante.';
$pia_lang['BackDevices_DBTools_DelDev_a'] = 'Appareil effacé avec succès.';
$pia_lang['BackDevices_DBTools_DelDev_b'] = 'Appareils supprimés avec succès.';
$pia_lang['BackDevices_DBTools_DelEvents'] = 'Événements supprimés avec succès.';
$pia_lang['BackDevices_DBTools_DelEventsError'] = 'Erreur lors de la suppression des événements.';
$pia_lang['BackDevices_DBTools_DelDevError_a'] = 'Erreur lors de l&apos;effacement de l&apos;appareil.';
$pia_lang['BackDevices_DBTools_DelDevError_b'] = 'Erreur lors de la suppression des appareils.';
$pia_lang['BackDevices_DBTools_UpdDev'] = 'Appareil mis à jour avec succès.';
$pia_lang['BackDevices_DBTools_UpdDevError'] = 'Erreur lors de la mise à jour de l&apos;appareil.';
$pia_lang['BackDevices_DBTools_Purge'] = 'Les sauvegardes les plus anciennes ont été supprimées.';
$pia_lang['BackDevices_DBTools_DelActHistory'] = 'L&apos;indicateur d&apos;activité réseau a été réinitialisé.';
$pia_lang['BackDevices_DBTools_DelActHistoryError'] = 'Erreur de réinitialisation de l&apos;indicateur d&apos;activité du réseau.';
$pia_lang['BackDevices_DBTools_DelInactHosts'] = 'Les hôtes inactifs ont été supprimés.';
$pia_lang['BackDevices_DBTools_DelInactHostsError'] = 'Une erreur s&apos;est produite lors de la tentative de suppression des hôtes inactifs.';
$pia_lang['BackDevices_Login_disabled'] = 'Login désactivé.';
$pia_lang['BackDevices_Login_enabled'] = 'Login activé.';
$pia_lang['BackDevices_Theme_set'] = 'Le thème est appliqué.';
$pia_lang['BackDevices_Theme_notset'] = 'Le thème n&apos;est pas appliqué.';
$pia_lang['BackDevices_Theme_invalid'] = 'Aucun thème sélectionné.';
$pia_lang['BackDevices_Language_set'] = 'La langue est appliquée.';
$pia_lang['BackDevices_Language_notset'] = 'La langue n&apos;est pas appliquée';
$pia_lang['BackDevices_Language_invalid'] = 'Aucune langue n&apos;est sélectionnée';
$pia_lang['BackDevices_DevListCol_noti_text'] = 'Le réglage du tableau est enregistré.';
$pia_lang['BackDevices_ConfEditor_CopError'] = "La sauvegarde de la configuration n'est pas possible.";
$pia_lang['BackDevices_ConfEditor_CopOkay'] = 'La sauvegarde de la configuration est terminée.';
$pia_lang['BackDevices_ConfEditor_RestoreError'] = 'La dernière version de la configuration n&apos;a pas pu être restaurée.';
$pia_lang['BackDevices_ConfEditor_RestoreOkay'] = 'La dernière version de la configuration a été restaurée.';
$pia_lang['BackDevices_Report_Delete'] = ' La/les notification(s) a/ont été supprimées.';

//////////////////////////////////////////////////////////////////
// Network Page
//////////////////////////////////////////////////////////////////

$pia_lang['Network_Title'] = 'Aperçu du réseau';
$pia_lang['Network_ManageDevices'] = 'Gérer les éléments du réseau';
$pia_lang['Network_ManageAdd_Name'] = 'Nom de l&apos;appareil';
$pia_lang['Network_ManageAdd_Name_text'] = 'Nom sans caractères spéciaux';
$pia_lang['Network_ManageAdd_Type'] = 'Type d&apos;appareil';
$pia_lang['Network_ManageAdd_Type_text'] = '-- Choisir le type --';
$pia_lang['Network_ManageAdd_Port'] = 'Nombre de ports';
$pia_lang['Network_ManageAdd_Port_text'] = 'laisser vide pour WLAN ou Powerline';
$pia_lang['Network_ManageAdd_Submit'] = 'Ajouter';
$pia_lang['Network_ManageEdit_ID'] = 'Sélectionner l&apos;appareil à modifier';
$pia_lang['Network_ManageEdit_ID_text'] = '-- Choisir l&apos;appareil --';
$pia_lang['Network_ManageEdit_Name'] = 'Nouveau nom';
$pia_lang['Network_ManageEdit_Name_text'] = 'Laisser vide si aucune modification n&apos;est effectuée.';
$pia_lang['Network_ManageEdit_Type'] = 'Nouveau type';
$pia_lang['Network_ManageEdit_Type_text'] = '-- Choisir le type --';
$pia_lang['Network_ManageEdit_Port'] = 'Nouveau nombre de ports';
$pia_lang['Network_ManageEdit_Port_text'] = 'Laisser vide pour WLAN ou Powerline';
$pia_lang['Network_ManageEdit_Downlink'] = 'configuration manuelle des ports (MAC cible, port local)';
$pia_lang['Network_ManageEdit_Downlink_text'] = '0a:1b:3c:4d:5e:6f,16;Ziel-MAC 2,Port 2;';
$pia_lang['Network_ManageEdit_Submit'] = 'Sauver';
$pia_lang['Network_ManageDel_Name'] = 'Sélectionner l&apos;appareil à supprimer';
$pia_lang['Network_ManageDel_Name_text'] = '-- Choisir l&apos;appareil --';
$pia_lang['Network_ManageDel_Submit'] = 'Supprimer';
$pia_lang['Network_Table_State'] = 'Statut';
$pia_lang['Network_Table_Hostname'] = 'Nom de l&apos;appareil';
$pia_lang['Network_Table_IP'] = 'IP de l&apos;hôte';
$pia_lang['Network_UnassignedDevices'] = 'Appareils non attribués';
$pia_lang['NetworkSettings_Title'] = 'Paramètres - Aperçu du réseau';
$pia_lang['Network_ManageDevices_Intro'] = 'Cette section est utilisée pour créer des appareils transparents/sans IP (non gérés), tels que des concentrateurs ou des commutateurs, ainsi que des appareils actifs tels que des routeurs, des commutateurs gérés ou des points d&apos;accès qui influencent la structure du réseau. Les appareils déjà détectés par Pi.Alert doivent être recréés ici pour être affichés. La modification ou la suppression des appareils déjà détectés par Pi.Alert est indépendante de la liste "<span class="text-maroon help_faq_code">' . $pia_lang['Navigation_Devices'] . '</span>" et n&apos;a de signification que pour la page "<span class="text-maroon help_faq_code">' . $pia_lang['Navigation_Network'] . '</span>".';
$pia_lang['Network_Unmanaged_Devices'] = 'Gérer les appareils non scannables';
$pia_lang['Network_Unmanaged_Devices_Intro'] = 'À cet endroit, vous pouvez créer des appareils finaux qui occupent des ports ou des connexions sur des commutateurs ou des routeurs mais qui n&apos;ont pas eux-mêmes de fonctionnalité réseau. Les appareils qui ne peuvent pas être détectés mais qui doivent être affichés pour une vue d&apos;ensemble peuvent également être pris en compte ici. Les appareils créés ici n&apos;apparaissent que sur la page "<span class="text-maroon help_faq_code">' . $pia_lang['Navigation_Network'] . '</span>".';
$pia_lang['Network_Unmanaged_Devices_Connected'] = 'Connecté à';
$pia_lang['Network_Unmanaged_Devices_Connected_text'] = 'Sélectionner un appareil';
$pia_lang['Network_Unmanaged_Devices_Port'] = 'Sur le port';
$pia_lang['Network_Unmanaged_Devices_Port_text'] = 'Sur le numéro de port de l&apos;appareil sélectionné';

//////////////////////////////////////////////////////////////////
// Help Page
//////////////////////////////////////////////////////////////////

$pia_lang['HelpFAQ_Title'] = 'Aide / FAQ';
$pia_lang['HelpFAQ_Cat_General'] = 'Généralités';
$pia_lang['HelpFAQ_Cat_Detail'] = 'Vue détaillée';
$pia_lang['HelpFAQ_Cat_General_100_head'] = 'L&apos;horloge en haut à droite et les heures des événements/présences ne sont pas correctes (décalage horaire).';
$pia_lang['HelpFAQ_Cat_General_100_text_a'] = 'Fuseau horaire actuellement configuré :';
$pia_lang['HelpFAQ_Cat_General_100_text_b'] = '<br>Si ce n&apos;est pas le fuseau horaire dans lequel tu te trouves, tu dois adapter le fuseau horaire dans le fichier de configuration PHP. Tu le trouveras dans le répertoire :';
$pia_lang['HelpFAQ_Cat_General_100_text_c'] = 'Cherche dans ce fichier l&apos;entrée "date.timezone", supprime le cas échéant le " ;" de tête et saisis le fuseau horaire souhaité. Tu trouveras une liste des fuseaux horaires supportés ici. (<a href="https://www.php.net/manual/fr/timezones.php" target="blank">Link</a>)';
$pia_lang['HelpFAQ_Cat_General_101_head'] = 'Mon réseau semble ralentir, le streaming "saccade".';
$pia_lang['HelpFAQ_Cat_General_101_text'] = 'Il est tout à fait possible que les appareils peu performants atteignent leurs limites de performance avec la manière dont Pi.Alert détecte les nouveaux appareils sur le réseau. Cela est encore plus vrai si ces appareils communiquent avec le réseau par WLAN. La solution serait alors de passer à une connexion câblée si possible ou, si l&apos;appareil ne doit être utilisé que pendant une période limitée, de mettre en pause le scan arp sur la page de maintenance.';
$pia_lang['HelpFAQ_Cat_General_102_head'] = 'Je reçois un message indiquant que la base de données est protégée en écriture (read only).';
$pia_lang['HelpFAQ_Cat_General_102_text'] = 'Vérifie dans le répertoire Pi.Alert si le dossier de la base de données (db) s&apos;est vu attribuer les bons droits :<br>
              								 <span class="text-maroon help_faq_code">drwxrwx---  2 (nombre de usuario) www-data</span><br>
              								 Si l&apos;autorisation n&apos;est pas correcte, tu peux la rétablir avec les commandes suivantes dans le terminal ou la console :<br>
              								 <div class="help_faq_code" style="padding-left: 10px; margin-bottom: 10px;">
              								 sudo chgrp -R www-data ~/pialert/db<br>
              								 sudo chown [Username]:www-data ~/pialert/db/pialert.db<br>
                							 chmod -R 770 ~/pialert/db
              								 </div>
              								 Vous pouvez également effectuer ces étapes en utilisant <span class="text-maroon help_faq_code">./pialert-cli set_permissions</span> dans le répertoire <span class="text-maroon help_faq_code">~/pialert/back</span>. Si la base de données reste en lecture seule après cela, essayez de réinstaller ou de restaurer une sauvegarde de la base de données via la page de maintenance. Veuillez vous assurer de vérifier et d&apos;ajuster les autorisations correspondantes.';
$pia_lang['HelpFAQ_Cat_General_103_head'] = 'La page de connexion n&apos;apparaît pas, même après la modification du mot de passe.';
$pia_lang['HelpFAQ_Cat_General_103_text'] = 'Outre le mot de passe, le paramètre <span class="text-maroon help_faq_code">PIALERT_WEB_PROTECTION = True</span> doit également être défini dans le fichier de configuration <span class="text-maroon help_faq_code">~/pialert/config/pialert.conf</span>.';
$pia_lang['HelpFAQ_Cat_General_104_head'] = 'Notes sur la migration de pucherot vers ce fork.';
$pia_lang['HelpFAQ_Cat_General_104_text'] = 'La base de données de ce fork a été étendue de quelques champs. Pour reprendre la base de données du Pi.Alert original (pucherot), il existe une possibilité de mise à niveau avec le script pialert-cli dans le répertoire ~/pialert/back. La commande est alors ./pialert-cli update_db';
$pia_lang['HelpFAQ_Cat_General_105_head'] = 'pialert-cli';
$pia_lang['HelpFAQ_Cat_General_105_text'] = 'The command line tool <span class="text-maroon help_faq_code">pialert-cli</span> is located in the directory <span class="text-maroon help_faq_code">~/pialert/back</span> and offers the possibility to make settings to Pi.Alert
                                             without web page or change to the configuration file. With the command <span class="text-maroon help_faq_code">./pialert-cli help</span> a list with the supported options can be called.
											 <table class="help_table_gen">
											    <tr><td class="help_table_gen_a">set_login</td>
											        <td class="help_table_gen_b">- Définit le paramètre PIALERT_WEB_PROTECTION dans le fichier de configuration sur TRUE<br>
											            - Si le paramètre n&apos;est pas présent, il sera créé. De plus, le mot de passe par défaut "123456" est défini.<br>&nbsp;</td></tr>
											    <tr><td class="help_table_gen_a">unset_login</td>
											        <td class="help_table_gen_b">- Définit le paramètre PIALERT_WEB_PROTECTION dans le fichier de configuration sur FALSE<br>
											            - Si le paramètre n&apos;est pas présent, il sera créé. De plus, le mot de passe par défaut "123456" est défini.<br>&nbsp;</td></tr>
											    <tr><td class="help_table_gen_a">set_password &lt;password&gt;</td>
											        <td class="help_table_gen_b">- Définit le nouveau mot de passe sous forme de valeur hachée.<br>
											            - Si le paramètre PIALERT_WEB_PROTECTION n&apos;existe pas encore, il sera créé et défini sur "TRUE" (connexion activée)<br>&nbsp;</td></tr>
											    <tr><td class="help_table_gen_a">set_autopassword</td>
											        <td class="help_table_gen_b">- Définit un nouveau mot de passe aléatoire sous forme de valeur hachée et l&apos;affiche en texte brut dans la console.<br>
											            - Si le paramètre PIALERT_WEB_PROTECTION n&apos;existe pas encore, il sera créé et défini sur "TRUE" (connexion activée)<br>&nbsp;</td></tr>
											    <tr><td class="help_table_gen_a">disable_scan &lt;MIN&gt;</td>
											        <td class="help_table_gen_b">- Arrête toutes les numérisations en cours.<br>
											            - Empêche le démarrage de nouvelles numérisations.<br>&nbsp;</td></tr>
											    <tr><td class="help_table_gen_a">enable_scan</td>
											        <td class="help_table_gen_b">- Permet le démarrage de nouvelles numérisations.<br>&nbsp;</td></tr>
												<tr><td class="help_table_gen_a">disable_mainscan</td>
												    <td class="help_table_gen_b">- Désactive la méthode principale de numérisation pour Pi.Alert (numérisation ARP)</td></tr>
												<tr><td class="help_table_gen_a">enable_mainscan</td>
												    <td class="help_table_gen_b">- Active la méthode principale de numérisation pour Pi.Alert (numérisation ARP)</td></tr>
											    <tr><td class="help_table_gen_a">enable_service_mon</td>
											        <td class="help_table_gen_b">- Active la surveillance des services Web.<br>&nbsp;</td></tr>
											    <tr><td class="help_table_gen_a">disable_service_mon</td>
											        <td class="help_table_gen_b">- Désactive la surveillance des services Web.<br>&nbsp;</td></tr>
											    <tr><td class="help_table_gen_a">enable_icmp_mon</td>
											        <td class="help_table_gen_b">- Enable ICMP Monitoring (ping)<br>&nbsp;</td></tr>
											    <tr><td class="help_table_gen_a">disable_icmp_mon</td>
											        <td class="help_table_gen_b">- Disable ICMP Monitoring (ping)<br>&nbsp;</td></tr>
											    <tr><td class="help_table_gen_a">update_db</td>
											        <td class="help_table_gen_b">- Le script tente de rendre la base de données compatible avec cette version.<br>&nbsp;</td></tr>
											    <tr><td class="help_table_gen_a">set_apikey</td>
											        <td class="help_table_gen_b">- Avec la clé API, il est possible de faire des requêtes à la base de données sans utiliser la page web. Si une clé API existe déjà, elle sera remplacée.<br>&nbsp;</td></tr>
											    <tr><td class="help_table_gen_a">set_permissions</td>
												    <td class="help_table_gen_b">- Corrige les permissions de fichier de la base de données.</td></tr>
											    <tr><td class="help_table_gen_a">reporting_test</td>
											        <td class="help_table_gen_b">- Teste les notifications pour tous les services activés.<br>&nbsp;</td></tr>
											    <tr><td class="help_table_gen_a">set_sudoers</td>
											        <td class="help_table_gen_b">- Create sudoer file for www-data and Pi.Alert user</td></tr>
											    <tr><td class="help_table_gen_a">unset_sudoers</td>
											        <td class="help_table_gen_b">- Delete sudoer file for www-data and Pi.Alert user</td></tr>
											</table>';
$pia_lang['HelpFAQ_Cat_General_106_head'] = '<span class="text-maroon help_faq_code">Certaines composantes de Pi.Alert nécessitent l&apos;autorisation "sudo"</span>';
$pia_lang['HelpFAQ_Cat_General_106_text'] = 'Certaines fonctionnalités de Pi.Alert, telles que l&apos;envoi de messages de test, la détection de serveurs DHCP étrangers ou l&apos;identification de périphériques à l&apos;aide de arp-scan,
											 nécessitent des autorisations "sudo". Un ajustement de configuration est nécessaire pour cela. Pour ce faire, dans le répertoire <span class="text-maroon help_faq_code">~/pialert/back</span>,
											 exécutez la commande <span class="text-maroon help_faq_code">sudo ./pialert-cli set_sudoers</span>.';
$pia_lang['HelpFAQ_Cat_General_107_head'] = 'pialert.conf';
$pia_lang['HelpFAQ_Cat_General_107_text'] = 'Le fichier <span class="text-maroon help_faq_code">pialert.conf</span> se trouve dans le répertoire <span class="text-maroon help_faq_code">~/pialert/config</span>.
											 Dans ce fichier de configuration, de nombreuses fonctions de Pi.Alert peuvent être configurées selon les préférences personnelles. Comme les possibilités sont variées, je souhaiterais donner une
											 brève explication des points individuels.
											 <table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">General Settings</td></tr>
											    <tr><td class="help_table_gen_a">PIALERT_PATH</td>
											        <td class="help_table_gen_b">Cette variable est définie lors de l&apos;installation et ne doit pas être modifiée.</td></tr>
											    <tr><td class="help_table_gen_a">DB_PATH</td>
											        <td class="help_table_gen_b">Cette variable est définie lors de l&apos;installation et ne doit pas être modifiée.</td></tr>
											    <tr><td class="help_table_gen_a">LOG_PATH</td>
											        <td class="help_table_gen_b">Cette variable est définie lors de l&apos;installation et ne doit pas être modifiée.</td></tr>
											    <tr><td class="help_table_gen_a">PRINT_LOG</td>
											        <td class="help_table_gen_b">Si cette entrée est définie sur <span class="text-maroon help_faq_code">True</span>, des horodatages supplémentaires pour les sous-fonctions individuelles sont ajoutés au journal de balayage. Par défaut, cette entrée est définie sur <span class="text-maroon help_faq_code">False</span></td></tr>
											    <tr><td class="help_table_gen_a">VENDORS_DB</td>
											        <td class="help_table_gen_b">Cette variable est définie lors de l&apos;installation et ne doit pas être modifiée.</td></tr>
											    <tr><td class="help_table_gen_a">PIALERT_APIKEY</td>
											        <td class="help_table_gen_b">Avec la clé API, il est possible d&apos;effectuer des requêtes à la base de données sans utiliser la page web. La clé API est une chaîne aléatoire qui peut être définie via les paramètres ou via <span class="text-maroon help_faq_code">pialert-cli</span></td></tr>
											    <tr><td class="help_table_gen_a">PIALERT_WEB_PROTECTION</td>
											        <td class="help_table_gen_b">Active ou désactive la protection par mot de passe de l&apos;interface web de Pi.Alert.</td></tr>
											    <tr><td class="help_table_gen_a">PIALERT_WEB_PASSWORD</td>
											        <td class="help_table_gen_b">Ce champ contient le mot de passe haché pour l&apos;interface web. Le mot de passe ne peut pas être saisi ici en texte brut, mais doit être défini avec <span class="text-maroon help_faq_code">pialert-cli</span></td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">Other Modules</td></tr>
											    <tr><td class="help_table_gen_a">SCAN_WEBSERVICES</td>
											        <td class="help_table_gen_b">Ici, la fonction de surveillance des services web peut être activée (<span class="text-maroon help_faq_code">True</span>) ou désactivée (<span class="text-maroon help_faq_code">False</span>)</td></tr>
											    <tr><td class="help_table_gen_a">ICMPSCAN_ACTIVE</td>
											        <td class="help_table_gen_b">ICMP Monitoring on/off</td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">Special Protocol Scanning</td></tr>
											    <tr><td class="help_table_gen_a">SCAN_ROGUE_DHCP</td>
											        <td class="help_table_gen_b">Active la recherche de serveurs DHCP étrangers, également appelés "rogue". Cette fonction est utilisée pour détecter la présence d&apos;un serveur DHCP étranger dans le réseau qui pourrait prendre le contrôle de la gestion des adresses IP.</td></tr>
											    <tr><td class="help_table_gen_a">DHCP_SERVER_ADDRESS</td>
											        <td class="help_table_gen_b">L&apos;adresse IP du serveur DHCP connu est stockée ici.</td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">Mail-Account Settings</td></tr>
											    <tr><td class="help_table_gen_a">SMTP_SERVER</td>
											        <td class="help_table_gen_b">Adresse du serveur de messagerie (par exemple, smtp.gmail.com)</td></tr>
											    <tr><td class="help_table_gen_a">SMTP_PORT</td>
											        <td class="help_table_gen_b">Le port du serveur SMTP. Le port peut varier en fonction de la configuration du serveur.</td></tr>
											    <tr><td class="help_table_gen_a">SMTP_USER</td>
											        <td class="help_table_gen_b">Nom d&apos;utilisateur</td></tr>
											    <tr><td class="help_table_gen_a">SMTP_PASS</td>
											        <td class="help_table_gen_b">Mot de passe</td></tr>
											    <tr><td class="help_table_gen_a">SMTP_SKIP_TLS</td>
											        <td class="help_table_gen_b">Si cette entrée est définie sur <span class="text-maroon help_faq_code">True</span>, le chiffrement de transport de l&apos;e-mail est activé. Si le serveur ne prend pas en charge cela, l&apos;entrée doit être définie sur <span class="text-maroon help_faq_code">False</span>.</td></tr>
											    <tr><td class="help_table_gen_a">SMTP_SKIP_LOGIN</td>
											        <td class="help_table_gen_b">Il existe des serveurs SMTP qui ne nécessitent pas de connexion. Dans ce cas, cette valeur peut être définie sur <span class="text-maroon help_faq_code">True</span>.</td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">WebGUI Reporting</td></tr>
											    <tr><td class="help_table_gen_a">REPORT_WEBGUI</td>
											        <td class="help_table_gen_b">Active/désactive les notifications concernant les changements dans le réseau dans l&apos;interface web.</td></tr>
											    <tr><td class="help_table_gen_a">REPORT_WEBGUI_WEBMON</td>
											        <td class="help_table_gen_b">Active/désactive les notifications concernant les changements dans les services web surveillés dans l&apos;interface web.</td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">Mail Reporting</td></tr>
											    <tr><td class="help_table_gen_a">REPORT_MAIL</td>
											        <td class="help_table_gen_b">Active/désactive les notifications concernant les changements dans le réseau via e-mail.</td></tr>
											    <tr><td class="help_table_gen_a">REPORT_MAIL_WEBMON</td>
											        <td class="help_table_gen_b">Active/désactive les notifications concernant les changements dans les services web surveillés par e-mail.</td></tr>
											    <tr><td class="help_table_gen_a">REPORT_FROM</td>
											        <td class="help_table_gen_b">Nom ou identifiant de l&apos;expéditeur.</td></tr>
											    <tr><td class="help_table_gen_a">REPORT_TO</td>
											        <td class="help_table_gen_b">Adresse e-mail à laquelle la notification doit être envoyée.</td></tr>
											    <tr><td class="help_table_gen_a">REPORT_DEVICE_URL</td>
											        <td class="help_table_gen_b">URL de l&apos;installation de Pi.Alert pour créer un lien cliquable dans l&apos;e-mail vers le périphérique détecté.</td></tr>
											    <tr><td class="help_table_gen_a">REPORT_DASHBOARD_URL</td>
											        <td class="help_table_gen_b">URL de l&apos;installation de Pi.Alert, pour pouvoir créer un lien cliquable dans l&apos;e-mail.</td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">Pushsafer</td></tr>
											    <tr><td class="help_table_gen_a">REPORT_PUSHSAFER</td>
											        <td class="help_table_gen_b">Active/désactive les notifications concernant les changements dans le réseau via Pushsafer.</td></tr>
											    <tr><td class="help_table_gen_a">REPORT_PUSHSAFER_WEBMON</td>
											        <td class="help_table_gen_b">Active/désactive les notifications concernant les changements dans les services web surveillés via Pushsafer.</td></tr>
											    <tr><td class="help_table_gen_a">PUSHSAFER_TOKEN</td>
											        <td class="help_table_gen_b">Il s&apos;agit de la clé privée qui peut être consultée sur la page Pushsafer.</td></tr>
											    <tr><td class="help_table_gen_a">PUSHSAFER_DEVICE</td>
											        <td class="help_table_gen_b">L&apos;ID du périphérique vers lequel le message sera envoyé. &lsquo;<span class="text-maroon help_faq_code">a</span>&rsquo; signifie que le message sera envoyé à tous les périphériques configurés et consommera un nombre correspondant d&apos;appels API.</td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">Pushover</td></tr>
											    <tr><td class="help_table_gen_a">REPORT_PUSHOVER</td>
											        <td class="help_table_gen_b">Active/désactive les notifications concernant les changements dans le réseau via Pushover.</td></tr>
											    <tr><td class="help_table_gen_a">REPORT_PUSHOVER_WEBMON</td>
											        <td class="help_table_gen_b">Active/désactive les notifications concernant les changements dans les services web surveillés via Pushover.</td></tr>
											    <tr><td class="help_table_gen_a">PUSHOVER_TOKEN</td>
											        <td class="help_table_gen_b">Aussi appelé "APP TOKEN" ou "API TOKEN". Ce jeton peut être consulté sur la page Pushover.</td></tr>
											    <tr><td class="help_table_gen_a">PUSHOVER_USER</td>
											        <td class="help_table_gen_b">Aussi appelé "USER KEY". Cette clé s&apos;affiche immédiatement après la connexion sur la page d&apos;accueil.</td></tr>
											</table>
											<table class="help_table_gen">
					    						<tr><td class="help_table_gen_section" colspan="2">NTFY</td></tr>
											    <tr><td class="help_table_gen_a">REPORT_NTFY</td>
											        <td class="help_table_gen_b">Active/désactive les notifications concernant les changements dans le réseau via NTFY.</td></tr>
											    <tr><td class="help_table_gen_a">REPORT_NTFY_WEBMON</td>
											        <td class="help_table_gen_b">Active/désactive les notifications concernant les changements dans les services web surveillés via NTFY.</td></tr>
											    <tr><td class="help_table_gen_a">NTFY_HOST</td>
											        <td class="help_table_gen_b">    </td></tr>
											    <tr><td class="help_table_gen_a">NTFY_TOPIC</td>
											        <td class="help_table_gen_b">    </td></tr>
											    <tr><td class="help_table_gen_a">NTFY_USER</td>
											        <td class="help_table_gen_b">    </td></tr>
											    <tr><td class="help_table_gen_a">NTFY_PASSWORD</td>
											        <td class="help_table_gen_b">    </td></tr>
											    <tr><td class="help_table_gen_a">NTFY_PRIORITY</td>
											        <td class="help_table_gen_b">    </td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">Shoutrrr</td></tr>
											    <tr><td class="help_table_gen_a">SHOUTRRR_BINARY</td>
											        <td class="help_table_gen_b">Ici, vous devez configurer le binaire de shoutrrr à utiliser. Cela dépend du matériel sur lequel Pi.Alert a été installé.</td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">Telegram via Shoutrrr</td></tr>
											    <tr><td class="help_table_gen_a">REPORT_TELEGRAM</td>
											        <td class="help_table_gen_b">Active/désactive les notifications concernant les changements dans le réseau via Telegram</td></tr>
											    <tr><td class="help_table_gen_a">REPORT_TELEGRAM_WEBMON</td>
											        <td class="help_table_gen_b">Active/désactive les notifications concernant les changements dans les services web surveillés via Telegram</td></tr>
											    <tr><td class="help_table_gen_a">TELEGRAM_BOT_TOKEN_URL</td>
											        <td class="help_table_gen_b">    </td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">DynDNS and IP</td></tr>
											    <tr><td class="help_table_gen_a">QUERY_MYIP_SERVER</td>
											        <td class="help_table_gen_b">    </td></tr>
											    <tr><td class="help_table_gen_a">DDNS_ACTIVE</td>
											        <td class="help_table_gen_b">Active/désactive le service DDNS configuré dans Pi.Alert. DDNS, également connu sous le nom de DynDNS, vous permet de mettre à jour un nom de domaine avec une adresse IP qui change régulièrement. Ce service est proposé par plusieurs fournisseurs de services.</td></tr>
											    <tr><td class="help_table_gen_a">DDNS_DOMAIN</td>
											        <td class="help_table_gen_b">    </td></tr>
											    <tr><td class="help_table_gen_a">DDNS_USER</td>
											        <td class="help_table_gen_b">    </td></tr>
											    <tr><td class="help_table_gen_a">DDNS_PASSWORD</td>
											        <td class="help_table_gen_b">    </td></tr>
											    <tr><td class="help_table_gen_a">DDNS_UPDATE_URL</td>
											        <td class="help_table_gen_b">    </td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">Arp-scan Options & Samples</td></tr>
											        <td class="help_table_gen_b">
											            <span class="text-maroon help_faq_code">[&apos;MAC-Address 1&apos;, &apos;MAC-Address 2&apos;]</span><br>
											            Cette (ces) adresse(s) MAC (à mémoriser avec des petites lettres) sera(ont) filtrée(s) à partir des résultats du scan.</td></tr>
											    <tr><td class="help_table_gen_a">SCAN_SUBNETS</td>
											        <td class="help_table_gen_b">
											        	&lsquo;<span class="text-maroon help_faq_code">--localnet</span>&rsquo;<br>
											        	Normalement, cette option est déjà paramétrée correctement. Ce paramètre est sélectionné lorsque Pi.Alert est installé sur un appareil avec une carte réseau et qu&apos;aucun autre réseau n&apos;est configuré.<br><br>
											        	&apos;<span class="text-maroon help_faq_code">--localnet --interface=eth0</span>&apos;<br>
											        	Cette configuration est sélectionnée si Pi.Alert est installé sur un système avec au moins 2 cartes réseau et un réseau configuré. Cependant, la désignation de l&apos;interface peut varier et doit être adaptée aux conditions du système.<br><br>
											        	<span class="text-maroon help_faq_code">[&apos;192.168.1.0/24 --interface=eth0&apos;,&apos;192.168.2.0/24 --interface=eth1&apos;]</span><br>
											        	La dernière configuration est nécessaire si plusieurs réseaux doivent être surveillés. Pour chaque réseau à surveiller, une carte réseau correspondante doit être configurée. Cela est nécessaire car le "arp-scan" utilisé n&apos;est pas routé, c&apos;est-à-dire qu&apos;il fonctionne uniquement dans son propre sous-réseau. Chaque interface est saisie ici avec le réseau correspondant. La désignation de l&apos;interface doit être adaptée aux conditions du système.
											        </td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">Options de Surveillance ICMP</td></tr>
											    <tr><td class="help_table_gen_a">ICMP_ONLINE_TEST</td>
											        <td class="help_table_gen_b">Nombre d&apos;essais pour déterminer si un appareil est en ligne (Par défaut 1).</td></tr>
											    <tr><td class="help_table_gen_a">ICMP_GET_AVG_RTT</td>
											        <td class="help_table_gen_b">Nombre de "ping&apos;s" pour calculer le temps de réponse moyen (Par défaut 2).</td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">Pi-hole Configuration</td></tr>
											    <tr><td class="help_table_gen_a">PIHOLE_ACTIVE</td>
											        <td class="help_table_gen_b">Cette variable est définie lors de l&apos;installation.</td></tr>
											    <tr><td class="help_table_gen_a">PIHOLE_DB</td>
											        <td class="help_table_gen_b">Cette variable est définie lors de l&apos;installation et ne doit pas être modifiée.</td></tr>
											    <tr><td class="help_table_gen_a">DHCP_ACTIVE</td>
											        <td class="help_table_gen_b">Cette variable est définie lors de l&apos;installation.</td></tr>
											    <tr><td class="help_table_gen_a">DHCP_LEASES</td>
											        <td class="help_table_gen_b">Cette variable est définie lors de l&apos;installation et ne doit pas être modifiée.</td></tr>
											</table>
											<table class="help_table_gen">
					    						<tr><td class="help_table_gen_section" colspan="2">Fritzbox Configuration</td></tr>
											    <tr><td class="help_table_gen_a">FRITZBOX_ACTIVE</td>
											        <td class="help_table_gen_b">Si une Fritzbox est utilisée dans le réseau, elle peut être utilisée comme source de données. Cela peut être activé ou désactivé à ce niveau.</td></tr>
											    <tr><td class="help_table_gen_a">FRITZBOX_IP</td>
											        <td class="help_table_gen_b">Adresse IP de la Fritzbox.</td></tr>
											    <tr><td class="help_table_gen_a">FRITZBOX_USER</td>
											        <td class="help_table_gen_b">Nom d&apos;utilisateur<br>Cela suppose que la Fritzbox est configurée pour une connexion avec nom d&apos;utilisateur et mot de passe, au lieu de mot de passe seul. Une connexion avec mot de passe seul n&apos;est pas prise en charge.</td></tr>
											    <tr><td class="help_table_gen_a">FRITZBOX_PASS</td>
											        <td class="help_table_gen_b">Mot de passe</td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">Configuration Mikrotik</td></tr>
											    <tr><td class="help_table_gen_a">MIKROTIK_ACTIVE</td>
											        <td class="help_table_gen_b">Si un routeur Mikrotik est utilisé dans le réseau, il peut être utilisé comme source de données. Cela peut être activé ou désactivé à ce stade.</td></tr>
											    <tr><td class="help_table_gen_a">MIKROTIK_IP</td>
											        <td class="help_table_gen_b">Adresse IP du routeur Mikrotik.</td></tr>
											    <tr><td class="help_table_gen_a">MIKROTIK_USER</td>
											        <td class="help_table_gen_b">Nom d&apos;utilisateur</td></tr>
											    <tr><td class="help_table_gen_a">MIKROTIK_PASS</td>
											        <td class="help_table_gen_b">Mot de passe</td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">Configuration UniFi</td></tr>
											    <tr><td class="help_table_gen_a">UNIFI_ACTIVE</td>
											        <td class="help_table_gen_b">Si un système UniFi est utilisé dans le réseau, il peut être utilisé comme source de données. Cela peut être activé ou désactivé à ce stade.</td></tr>
											    <tr><td class="help_table_gen_a">UNIFI_IP</td>
											        <td class="help_table_gen_b">Adresse IP du système Unifi.</td></tr>
											    <tr><td class="help_table_gen_a">UNIFI_USER</td>
											        <td class="help_table_gen_b">Nom d&apos;utilisateur</td></tr>
											    <tr><td class="help_table_gen_a">UNIFI_PASS</td>
											        <td class="help_table_gen_b">Mot de passe</td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">Maintenance Tasks Cron</td></tr>
											    <tr><td class="help_table_gen_a">DAYS_TO_KEEP_ONLINEHISTORY</td>
											        <td class="help_table_gen_b">Nombre de jours pendant lesquels l&apos;historique en ligne (graphique d&apos;activité) doit être stocké dans la base de données. Un jour génère 288 enregistrements de ce type.</td></tr>
											    <tr><td class="help_table_gen_a">DAYS_TO_KEEP_EVENTS</td>
											        <td class="help_table_gen_b">Nombre de jours pendant lesquels les événements des appareils individuels doivent être stockés.</td></tr>
											</table>';
$pia_lang['HelpFAQ_Cat_Device_200_head'] = 'I have devices in my list that I do not know about. After deleting them, they always reappear.';
$pia_lang['HelpFAQ_Cat_Device_200_text'] = 'If you use Pi-hole, please note that Pi.Alert retrieves information from Pi-hole. Pause Pi.Alert, go to the settings page in Pi-hole and
         									delete the DHCP lease if necessary. Then, also in Pi-hole, look under Tools -> Network to see if you can find the recurring hosts there.
         									If yes, delete them there as well. Now you can start Pi.Alert again. Now the device(s) should not show up anymore. Restarting the <span class="text-maroon help_faq_code">pihole-FTL</span> service may also fix the problem.
         									Si un tel appareil continue à apparaître de manière répétée, vous pouvez ajouter l&apos;adresse MAC à la liste d&apos;ignorés <span class="text-maroon help_faq_code">MAC_IGNORE_LIST</span> dans le fichier <span class="text-maroon help_faq_code">pialert.conf</span>.';
$pia_lang['HelpFAQ_Cat_Detail_300_head'] = 'Que signifie ';
$pia_lang['HelpFAQ_Cat_Detail_300_text_a'] = 'signifie un appareil réseau créé à partir de la page réseau.';
$pia_lang['HelpFAQ_Cat_Detail_300_text_b'] = 'désigne le numéro de port auquel l&apos;appareil actuellement modifié est connecté à cet appareil réseau.';
$pia_lang['HelpFAQ_Cat_Detail_301_head_a'] = 'Quand se fait la numérisation maintenant ? À ';
$pia_lang['HelpFAQ_Cat_Detail_301_head_b'] = ' indique 1 minute mais le graphique montre des intervalles de 5 minutes.';
$pia_lang['HelpFAQ_Cat_Detail_301_text'] = 'L&apos;intervalle de temps entre les numérisations est défini par le "Cronjob", qui est réglé par défaut sur 5 minutes. La mention "1 minute" fait référence à la durée prévue de la numérisation.
											En fonction de la configuration du réseau, cette durée peut varier. Pour modifier le cronjob, vous pouvez utiliser la commande suivante dans le terminal/console <span class="text-maroon help_faq_code">crontab -e</span>
											et modifier l&apos;intervalle.';
$pia_lang['HelpFAQ_Cat_Detail_302_head_a'] = 'What means ';
$pia_lang['HelpFAQ_Cat_Detail_302_head_b'] = 'and why can&apos;t I select that?';
$pia_lang['HelpFAQ_Cat_Detail_302_text'] = 'Some modern devices generate random MAC addresses for privacy reasons, which can no longer be associated with any manufacturer and which change again with each new connection.
        									Pi.Alert detects if it is such a random MAC address and activates this "field" automatically. To disable this behavior you have to look in your device how to disable
        									MAC address randomization.';
$pia_lang['HelpFAQ_Cat_Detail_303_head'] = 'What is Nmap and what is it for?';
$pia_lang['HelpFAQ_Cat_Detail_303_text'] = 'Nmap is a network scanner with multiple capabilities.<br>
        									When a new device appears in your list, you have the possibility to get more detailed information about the device via the Nmap scan.';
$pia_lang['HelpFAQ_Cat_Presence_400_head'] = 'Devices are displayed with a yellow marker and the note "missing event".';
$pia_lang['HelpFAQ_Cat_Presence_400_text'] = 'If this happens, you have the option to delete the events on the device in question (details view). Another possibility would be to switch on the device and wait until Pi.Alert detects the device as "online" with the next
        									  scan and then simply turn the device off again. Now Pi.Alert should properly note the state of the device in the database with the next scan.';
$pia_lang['HelpFAQ_Cat_Presence_401_head'] = 'A device is displayed as present although it is "Offline".';
$pia_lang['HelpFAQ_Cat_Presence_401_text'] = 'If this happens, you have the possibility to delete the events for the device in question (details view). Another possibility would be to switch on the device and wait until Pi.Alert recognizes the device as "online" with the next scan
											  and then simply switch the device off again. Now Pi.Alert should properly note the state of the device in the database with the next scan.';
$pia_lang['HelpFAQ_Cat_Network_600_head'] = 'What is this page for?';
$pia_lang['HelpFAQ_Cat_Network_600_text'] = 'This page should offer you the possibility to map the assignment of your network devices. For this purpose, you can create one or more switches, WLANs, routers, etc., provide them with a port number if necessary and assign already detected
											 devices to them. This assignment is done in the detailed view of the device to be assigned. So it is possible for you to quickly determine to which port a host is connected and if it is online. It is possible to assign a device to multiple
											 ports (port bundling), as well as multiple devices to one port (virtual machines).';
$pia_lang['HelpFAQ_Cat_Network_601_head'] = 'How does the network page work?';
$pia_lang['HelpFAQ_Cat_Network_601_text'] = 'On the network side, for example, a switch is created. For this purpose, I already offer corresponding devices in the selection list. You continue to specify the type and the number of ports.<br><br>
											 On the detail view you have now, with each recognized device, the possibility to save this just created switch and the occupied port.<br><br>
											 Now the network page shows you the switch with its ports and the devices connected to it. For each device in the detail view, you have the option of assigning multiple ports to a switch, which you separate with a comma (e.g. for link aggregation). It is also possible to assign several devices to one port (e.g. a server with several virtual machines).<br><br>
											 You can also assign a switch to a router if you have created it on the network side. Normally, this switch will now be displayed on the router tab. What does not happen is that the router is displayed on the switch port. For this it is necessary and possible to save a manual port configuration. To do this, open the "Administration" and select the switch in the editing. After you have entered the type and the number of ports again, you have a selection list of possible devices in the lowest field. After the selection, only the MAC address is visible, followed by a ",". Now simply add the port of the router on the switch and save. It is also possible to enter multiple MAC addresses and ports. It is important to follow the syntax "MAC1,PortA;MAC2,PortB;MAC3,PortC".';
$pia_lang['HelpFAQ_Cat_Network_602_head'] = 'A switch or router is shown to me without ports.';
$pia_lang['HelpFAQ_Cat_Network_602_text'] = 'It is possible that the number of ports was not entered when the device was created on the network page. When editing the device on the network page, it is also necessary to enter an already entered number of ports again.<br>
											 If the number of ports is missing for a device that has already been created, the problem should be solved by editing the device and specifying the ports, the type and, if necessary, the manual port configuration.';
$pia_lang['HelpFAQ_Cat_Service_700_head'] = 'What do the different colors in the colored bar mean?';
$pia_lang['HelpFAQ_Cat_Service_700_text'] = 'There are 5 different color codes in total: <br>
											 <span style="background-color:lightgray;">&nbsp;&nbsp;&nbsp;</span> - no scan available yet<br>
											 <span class="bg-green">&nbsp;&nbsp;&nbsp;</span> - HTTP status code 2xx<br>
											 <span class="bg-yellow">&nbsp;&nbsp;&nbsp;</span> - HTTP status code 3xx-4xx<br>
											 <span class="bg-orange-custom">&nbsp;&nbsp;&nbsp;</span> - HTTP status code 5xx<br>
											 <span class="bg-red">&nbsp;&nbsp;&nbsp;</span> - offline';
$pia_lang['HelpFAQ_Cat_Service_701_head'] = 'What are the HTTP status codes?';
// from json
$pia_lang['HelpFAQ_Cat_Service_702_head'] = 'What changes are reported?';
$pia_lang['HelpFAQ_Cat_Service_702_text'] = 'Detectable events are:<br>
												<ul>
													<li>Changing the HTTP status code</li>
													<li>Change IP</li>
													<li>Response time of the server or the missing of the response.</li>
												</ul>
											 Depending on the choice of notification, either everything is reported, or only the absence of a server response.';
$pia_lang['HelpFAQ_Cat_Service_703_head'] = 'General information about "Web Service Monitoring".';
$pia_lang['HelpFAQ_Cat_Service_703_text'] = 'The monitoring is based exclusively on the responses of HTTP requests sent to the page. Depending on the state of the server, meaningful error patterns can be detected here. If the server does not respond at all, this is considered as "Down/Offline". These web server requests are performed every 10 min as part of the normal scan.';
$pia_lang['HelpFAQ_Cat_ServiceDetails_750_head'] = 'I cannot edit all the fields.';
$pia_lang['HelpFAQ_Cat_ServiceDetails_750_text'] = 'Not every field that is displayed on this page can be edited. Editable fields are:
													<ul>
														<li>' . $pia_lang['WebServices_label_Tags'] . '</li>
														<li>' . $pia_lang['WebServices_label_MAC'] . ' (possibly a device to which this web service is assigned)<br>
															A MAC address is expected here. If something else (e.g. "laptop") is entered here, "' . $pia_lang['WebServices_unknown_Device'] . ' (laptop)" appears in the overview..
															Services without this entry are listed under "' . $pia_lang['WebServices_BoxTitle_General'] . '".</li>
														<li>CheckBox: ' . $pia_lang['WebServices_Events_all'] . '</li>
														<li>CheckBox: ' . $pia_lang['WebServices_Events_down'] . '</li>
													</ul>';

//////////////////////////////////////////////////////////////////
// Reports Page
//////////////////////////////////////////////////////////////////

$pia_lang['Reports_Title'] = 'Notifications';
$pia_lang['Reports_delete_all'] = 'Supprimer toutes les notifications';
$pia_lang['Reports_delete_all_noti'] = 'Supprimer toutes les notifications';
$pia_lang['Reports_delete_all_noti_text'] = 'Toutes les notifications sont supprimées. Le compteur est ainsi remis à zéro.';
$pia_lang['Reports_Rogue_hint'] = 'Un nouveau message concernant un serveur DHCP inconnu n&apos;est envoyé qu&apos;après la suppression de ce message.';

//////////////////////////////////////////////////////////////////
// UpdateCheck
//////////////////////////////////////////////////////////////////

$pia_lang['Maintenance_Tools_Updatecheck'] = 'Vérifier les mises à jour';
$pia_lang['Maintenance_Github_package_a'] = 'Dernière version : ';
$pia_lang['Maintenance_Github_package_b'] = 'heure';
$pia_lang['Updatecheck_Title'] = 'Vérification des mises à jour';
$pia_lang['Updatecheck_cur'] = 'Version actuellement utilisée de Pi.Alert';
$pia_lang['Updatecheck_new'] = 'Dernière version de Pi.Alert sur Github';
$pia_lang['GeoLiteDB_Title'] = 'Remarques sur la base de données GeoLite2';
$pia_lang['GeoLiteDB_cur'] = 'Base de données GeoLite2 chargée le';
$pia_lang['GeoLiteDB_new'] = 'Dernière base de données GeoLite2 sur Github';
$pia_lang['Updatecheck_RN'] = 'Notes de mise à jour de Pi.Alert';
$pia_lang['Updatecheck_RN2'] = 'Pi.Alert Update Check';
$pia_lang['Updatecheck_U2D'] = 'Vous utilisez déjà la dernière version';
$pia_lang['GeoLiteDB_button_del'] = 'Supprimer la base de données GeoLite2';
$pia_lang['GeoLiteDB_button_ins'] = 'Installer la base de données GeoLite2';
$pia_lang['GeoLiteDB_credits'] = 'La base de données est téléchargée depuis <a href="https://github.com/P3TERX/GeoLite.mmdb" target="_blank">github.com/P3TERX/GeoLite.mmdb</a>. La base de données GeoLite2 est un produit de <a href="https://dev.maxmind.com/geoip/geolite2-free-geolocation-data" target="_blank">MaxMind</a>.';
$pia_lang['GeoLiteDB_Installnotes'] = 'You can install the database via the ' . $pia_lang['WebServices_Tab_Graph'] . ' tab on the details page of any web service.';
$pia_lang['GeoLiteDB_absent'] = 'DB not installed';

//////////////////////////////////////////////////////////////////
// System Info Page
//////////////////////////////////////////////////////////////////

$pia_lang['SysInfo_storage_note'] = 'Il est possible que l&apos;utilisation de la mémoire ne puisse pas être déterminée pour tous les lecteurs énumérés ci-dessus. Cela dépend de l&apos;utilisateur sous lequel les lecteurs sont montés.';

// =============================================================================================================

$pia_journ_lang['Journal_TableHead_Class'] = 'Méthode';
$pia_journ_lang['Journal_TableHead_Trigger'] = 'Déclencheur';

$pia_journ_lang['Title'] = 'Journal d&apos;application';
$pia_journ_lang['File_hash'] = 'pialert.conf - Hachage';
// Frontend
$pia_journ_lang['a_000'] = 'Fichier de configuration';
$pia_journ_lang['a_001'] = 'Accès GUI';
$pia_journ_lang['a_002'] = 'Scans Pi.Alert';
$pia_journ_lang['a_005'] = 'Configuration GUI';
$pia_journ_lang['a_010'] = 'Maintenance BD';
$pia_journ_lang['a_020'] = 'Dispositifs';
$pia_journ_lang['a_021'] = 'Éditeur Multiple';
$pia_journ_lang['a_025'] = 'Outils';
$pia_journ_lang['a_030'] = 'Surveillance du service Web';
$pia_journ_lang['a_031'] = 'ICMP Monitoring';
$pia_journ_lang['a_032'] = 'Main Scan';
$pia_journ_lang['a_040'] = 'Aperçu du réseau';
$pia_journ_lang['a_050'] = 'Rapports';
$pia_journ_lang['a_060'] = 'Vérification des mises à jour';
$pia_journ_lang['a_070'] = 'API';
// pialert-cli
$pia_journ_lang['b_002'] = $pia_journ_lang['a_002'];
$pia_journ_lang['b_010'] = 'Maintenance BD';
$pia_journ_lang['b_030'] = $pia_journ_lang['a_030'];
$pia_journ_lang['b_031'] = $pia_journ_lang['a_031'];
$pia_journ_lang['b_032'] = $pia_journ_lang['a_032'];
// cronjob
$pia_journ_lang['c_002'] = $pia_journ_lang['a_002'];
$pia_journ_lang['c_010'] = $pia_journ_lang['a_010'];
// LogStrings
$pia_journ_lang['LogStr_0001'] = 'Entrée ajoutée';
$pia_journ_lang['LogStr_0002'] = 'Entrée modifiée';
$pia_journ_lang['LogStr_0003'] = 'Entrée supprimée';
$pia_journ_lang['LogStr_0004'] = 'Entrée modifiée (avec erreur)';
$pia_journ_lang['LogStr_0005'] = 'Entrée supprimée (avec erreur)';
$pia_journ_lang['LogStr_0006'] = 'Dernière modification du fichier de configuration annulée';
$pia_journ_lang['LogStr_0007'] = 'Sauvegarde de la configuration créée';
$pia_journ_lang['LogStr_0008'] = 'Base de données GeoLite2 installée';
$pia_journ_lang['LogStr_0009'] = 'Base de données GeoLite2 supprimée';
$pia_journ_lang['LogStr_0010'] = 'Base de données mise à jour';
$pia_journ_lang['LogStr_0011'] = 'Sauvegarde de la base de données créée';
$pia_journ_lang['LogStr_0012'] = 'Restauration de la sauvegarde de la base de données';
$pia_journ_lang['LogStr_0013'] = 'Nettoyage des sauvegardes (fichier de configuration et base de données)';
$pia_journ_lang['LogStr_0014'] = 'Suppression des hôtes inactifs (avec erreur)';
$pia_journ_lang['LogStr_0015'] = 'Suppression des hôtes inactifs';
$pia_journ_lang['LogStr_0016'] = 'Suppression de tous les hôtes sans adresse MAC';
$pia_journ_lang['LogStr_0017'] = 'Suppression de tous les hôtes sans adresse MAC (avec erreur)';
$pia_journ_lang['LogStr_0018'] = 'Suppression de tous les hôtes (inconnus)';
$pia_journ_lang['LogStr_0019'] = 'Suppression de tous les hôtes (inconnus) (avec erreur)';
$pia_journ_lang['LogStr_0020'] = 'Suppression de tous les événements d&apos;un dispositif';
$pia_journ_lang['LogStr_0021'] = 'Suppression de tous les événements d&apos;un dispositif (avec erreur)';
$pia_journ_lang['LogStr_0022'] = 'Suppression de tous les hôtes de la liste des dispositifs';
$pia_journ_lang['LogStr_0023'] = 'Suppression de tous les hôtes de la liste des dispositifs (avec erreur)';
$pia_journ_lang['LogStr_0024'] = 'Suppression de tous les événements';
$pia_journ_lang['LogStr_0025'] = 'Suppression de tous les événements (avec erreur)';
$pia_journ_lang['LogStr_0026'] = 'Réinitialisation de l&apos;activité réseau';
$pia_journ_lang['LogStr_0027'] = 'Réinitialisation de l&apos;activité réseau (avec erreur)';
$pia_journ_lang['LogStr_0030'] = 'Composant réseau actif ajouté (Switch, Routeur, etc.)';
$pia_journ_lang['LogStr_0031'] = 'Composant réseau actif modifié (Switch, Routeur, etc.)';
$pia_journ_lang['LogStr_0032'] = 'Composant réseau actif supprimé (Switch, Routeur, etc.)';
$pia_journ_lang['LogStr_0033'] = 'Appareil non scannable ajouté (Hubs, appareils PoE, Docker, etc.)';
$pia_journ_lang['LogStr_0034'] = 'Appareil non scannable modifié (Hubs, appareils PoE, Docker, etc.)';
$pia_journ_lang['LogStr_0035'] = 'Appareil non scannable supprimé (Hubs, appareils PoE, Docker, etc.)';
$pia_journ_lang['LogStr_0050'] = 'Protection par mot de passe de Pi.Alert activée';
$pia_journ_lang['LogStr_0051'] = 'Protection par mot de passe de Pi.Alert désactivée';
$pia_journ_lang['LogStr_0052'] = 'Modification de la configuration des colonnes de la liste des dispositifs';
$pia_journ_lang['LogStr_0053'] = 'Changement de thème';
$pia_journ_lang['LogStr_0054'] = 'Changement de langue';
$pia_journ_lang['LogStr_0055'] = $pia_lang['BackDevices_darkmode_disabled'];
$pia_journ_lang['LogStr_0056'] = $pia_lang['BackDevices_darkmode_enabled'];
$pia_journ_lang['LogStr_0057'] = $pia_lang['BackDevices_onlinehistorygraph_disabled'];
$pia_journ_lang['LogStr_0058'] = $pia_lang['BackDevices_onlinehistorygraph_enabled'];
$pia_journ_lang['LogStr_0061'] = 'Mise à jour Pi.Alert disponible';
$pia_journ_lang['LogStr_0062'] = 'Aucune mise à jour Pi.Alert disponible';
$pia_journ_lang['LogStr_0063'] = 'Mise à jour de la base de données GeoLite2 disponible';
$pia_journ_lang['LogStr_0064'] = 'Aucune mise à jour de la base de données GeoLite2 disponible';
$pia_journ_lang['LogStr_0065'] = 'Base de données GeoLite2 non installée';
$pia_journ_lang['LogStr_0101'] = 'Base de données nettoyée et optimisée';
$pia_journ_lang['LogStr_0210'] = 'Exécution d&apos;un scan nmap individuel';
$pia_journ_lang['LogStr_0251'] = 'Exécution de Wake-on-lan';
$pia_journ_lang['LogStr_0255'] = 'Exécution du test de vitesse en ligne';
$pia_journ_lang['LogStr_0301'] = $pia_lang['BackDevices_webservicemon_enabled'];
$pia_journ_lang['LogStr_0302'] = $pia_lang['BackDevices_webservicemon_disabled'];
$pia_journ_lang['LogStr_0500'] = 'Notification(s) de test envoyée(s)';
$pia_journ_lang['LogStr_0503'] = 'Rapport supprimé';
$pia_journ_lang['LogStr_0504'] = 'Supprimer tous les rapports';
$pia_journ_lang['LogStr_0510'] = 'Réactivation de Pi.Alert';
$pia_journ_lang['LogStr_0511'] = 'Pi.Alert désactivé (avec indication du temps)';
$pia_journ_lang['LogStr_0512'] = 'Pi.Alert désactivé (pendant 10 minutes)';
$pia_journ_lang['LogStr_0700'] = 'Clé API définie';
$pia_journ_lang['LogStr_9001'] = 'Accès à l&apos;interface web commencé';
$pia_journ_lang['LogStr_9002'] = 'Déconnexion effectuée';
$pia_journ_lang['LogStr_9003'] = 'Erreur de connexion (mot de passe incorrect !)';
$pia_journ_lang['LogStr_9004'] = 'Accès à l&apos;interface web commencé (avec cookie)';
$pia_journ_lang['LogStr_9991'] = $pia_lang['BackDevices_MainScan_enabled'];
$pia_journ_lang['LogStr_9992'] = $pia_lang['BackDevices_MainScan_disabled'];
$pia_journ_lang['LogStr_9999'] = 'Fichier de configuration modifié';

?>
