CKEDITOR.plugins.setLang("docprops","sl",{bgColor:"Barva ozadja",bgFixed:"Nepremično ozadje",bgImage:"URL slike za ozadje",charset:"Kodna tabela",charsetASCII:"ASCII",charsetCE:"Srednjeevropsko",charsetCR:"Cirilica",charsetCT:"Tradicionalno kitajsko (Big5)",charsetGR:"Grško",charsetJP:"Japonsko",charsetKR:"Korejsko",charsetOther:"Druga kodna tabela",charsetTR:"Turško",charsetUN:"Unicode (UTF-8)",charsetWE:"Zahodnoevropsko",chooseColor:"Izberi",design:"Oblika",docTitle:"Naslov strani",docType:"Glava vrste dokumenta",
docTypeOther:"Druga glava vrste dokumenta",label:"Lastnosti dokumenta",margin:"Robovi strani",marginBottom:"Spodaj",marginLeft:"Levo",marginRight:"Desno",marginTop:"Zgoraj",meta:"Metaoznake",metaAuthor:"Avtor",metaCopyright:"Avtorske pravice",metaDescription:"Opis dokumenta",metaKeywords:"Ključne besede dokumenta (ločene z vejicami)",other:"Drugo ...",previewHtml:'\x3cp\x3eTole je\x3cstrong\x3eprimer besedila\x3c/strong\x3e. Uporabljate \x3ca href\x3d"javascript:void(0)"\x3eCKEditor\x3c/a\x3e.\x3c/p\x3e',
title:"Lastnosti dokumenta",txtColor:"Barva besedila",xhtmlDec:"Vstavi XHTML deklaracije"});